XK_Hangul: int
XK_Hangul_Start: int
XK_Hangul_End: int
XK_Hangul_Hanja: int
XK_Hangul_Jamo: int
XK_Hangul_Romaja: int
XK_Hangul_Codeinput: int
XK_Hangul_Jeonja: int
XK_Hangul_Banja: int
XK_Hangul_PreHanja: int
XK_Hangul_PostHanja: int
XK_Hangul_SingleCandidate: int
XK_Hangul_MultipleCandidate: int
XK_Hangul_PreviousCandidate: int
XK_Hangul_Special: int
XK_Hangul_switch: int
XK_Hangul_Kiyeog: int
XK_Hangul_SsangKiyeog: int
XK_Hangul_KiyeogSios: int
XK_Hangul_Nieun: int
XK_Hangul_NieunJieuj: int
XK_Hangul_NieunHieuh: int
XK_Hangul_Dikeud: int
XK_Hangul_SsangDikeud: int
XK_Hangul_Rieul: int
XK_Hangul_RieulKiyeog: int
XK_Hangul_RieulMieum: int
XK_Hangul_RieulPieub: int
XK_Hangul_RieulSios: int
XK_Hangul_RieulTieut: int
XK_Hangul_RieulPhieuf: int
XK_Hangul_RieulHieuh: int
XK_Hangul_Mieum: int
XK_Hangul_Pieub: int
XK_Hangul_SsangPieub: int
XK_Hangul_PieubSios: int
XK_Hangul_Sios: int
XK_Hangul_SsangSios: int
XK_Hangul_Ieung: int
XK_Hangul_Jieuj: int
XK_Hangul_SsangJieuj: int
XK_Hangul_Cieuc: int
XK_Hangul_Khieuq: int
XK_Hangul_Tieut: int
XK_Hangul_Phieuf: int
XK_Hangul_Hieuh: int
XK_Hangul_A: int
XK_Hangul_AE: int
XK_Hangul_YA: int
XK_Hangul_YAE: int
XK_Hangul_EO: int
XK_Hangul_E: int
XK_Hangul_YEO: int
XK_Hangul_YE: int
XK_Hangul_O: int
XK_Hangul_WA: int
XK_Hangul_WAE: int
XK_Hangul_OE: int
XK_Hangul_YO: int
XK_Hangul_U: int
XK_Hangul_WEO: int
XK_Hangul_WE: int
XK_Hangul_WI: int
XK_Hangul_YU: int
XK_Hangul_EU: int
XK_Hangul_YI: int
XK_Hangul_I: int
XK_Hangul_J_Kiyeog: int
XK_Hangul_J_SsangKiyeog: int
XK_Hangul_J_KiyeogSios: int
XK_Hangul_J_Nieun: int
XK_Hangul_J_NieunJieuj: int
XK_Hangul_J_NieunHieuh: int
XK_Hangul_J_Dikeud: int
XK_Hangul_J_Rieul: int
XK_Hangul_J_RieulKiyeog: int
XK_Hangul_J_RieulMieum: int
XK_Hangul_J_RieulPieub: int
XK_Hangul_J_RieulSios: int
XK_Hangul_J_RieulTieut: int
XK_Hangul_J_RieulPhieuf: int
XK_Hangul_J_RieulHieuh: int
XK_Hangul_J_Mieum: int
XK_Hangul_J_Pieub: int
XK_Hangul_J_PieubSios: int
XK_Hangul_J_Sios: int
XK_Hangul_J_SsangSios: int
XK_Hangul_J_Ieung: int
XK_Hangul_J_Jieuj: int
XK_Hangul_J_Cieuc: int
XK_Hangul_J_Khieuq: int
XK_Hangul_J_Tieut: int
XK_Hangul_J_Phieuf: int
XK_Hangul_J_Hieuh: int
XK_Hangul_RieulYeorinHieuh: int
XK_Hangul_SunkyeongeumMieum: int
XK_Hangul_SunkyeongeumPieub: int
XK_Hangul_PanSios: int
XK_Hangul_KkogjiDalrinIeung: int
XK_Hangul_SunkyeongeumPhieuf: int
XK_Hangul_YeorinHieuh: int
XK_Hangul_AraeA: int
XK_Hangul_AraeAE: int
XK_Hangul_J_PanSios: int
XK_Hangul_J_KkogjiDalrinIeung: int
XK_Hangul_J_YeorinHieuh: int
XK_Korean_Won: int



XK_overline: int
XK_kana_fullstop: int
XK_kana_openingbracket: int
XK_kana_closingbracket: int
XK_kana_comma: int
XK_kana_conjunctive: int
XK_kana_middledot: int
XK_kana_WO: int
XK_kana_a: int
XK_kana_i: int
XK_kana_u: int
XK_kana_e: int
XK_kana_o: int
XK_kana_ya: int
XK_kana_yu: int
XK_kana_yo: int
XK_kana_tsu: int
XK_kana_tu: int
XK_prolongedsound: int
XK_kana_A: int
XK_kana_I: int
XK_kana_U: int
XK_kana_E: int
XK_kana_O: int
XK_kana_KA: int
XK_kana_KI: int
XK_kana_KU: int
XK_kana_KE: int
XK_kana_KO: int
XK_kana_SA: int
XK_kana_SHI: int
XK_kana_SU: int
XK_kana_SE: int
XK_kana_SO: int
XK_kana_TA: int
XK_kana_CHI: int
XK_kana_TI: int
XK_kana_TSU: int
XK_kana_TU: int
XK_kana_TE: int
XK_kana_TO: int
XK_kana_NA: int
XK_kana_NI: int
XK_kana_NU: int
XK_kana_NE: int
XK_kana_NO: int
XK_kana_HA: int
XK_kana_HI: int
XK_kana_FU: int
XK_kana_HU: int
XK_kana_HE: int
XK_kana_HO: int
XK_kana_MA: int
XK_kana_MI: int
XK_kana_MU: int
XK_kana_ME: int
XK_kana_MO: int
XK_kana_YA: int
XK_kana_YU: int
XK_kana_YO: int
XK_kana_RA: int
XK_kana_RI: int
XK_kana_RU: int
XK_kana_RE: int
XK_kana_RO: int
XK_kana_WA: int
XK_kana_N: int
XK_voicedsound: int
XK_semivoicedsound: int
XK_kana_switch: int



XK_ISO_Lock: int
XK_ISO_Level2_Latch: int
XK_ISO_Level3_Shift: int
XK_ISO_Level3_Latch: int
XK_ISO_Level3_Lock: int
XK_ISO_Group_Shift: int
XK_ISO_Group_Latch: int
XK_ISO_Group_Lock: int
XK_ISO_Next_Group: int
XK_ISO_Next_Group_Lock: int
XK_ISO_Prev_Group: int
XK_ISO_Prev_Group_Lock: int
XK_ISO_First_Group: int
XK_ISO_First_Group_Lock: int
XK_ISO_Last_Group: int
XK_ISO_Last_Group_Lock: int
XK_ISO_Left_Tab: int
XK_ISO_Move_Line_Up: int
XK_ISO_Move_Line_Down: int
XK_ISO_Partial_Line_Up: int
XK_ISO_Partial_Line_Down: int
XK_ISO_Partial_Space_Left: int
XK_ISO_Partial_Space_Right: int
XK_ISO_Set_Margin_Left: int
XK_ISO_Set_Margin_Right: int
XK_ISO_Release_Margin_Left: int
XK_ISO_Release_Margin_Right: int
XK_ISO_Release_Both_Margins: int
XK_ISO_Fast_Cursor_Left: int
XK_ISO_Fast_Cursor_Right: int
XK_ISO_Fast_Cursor_Up: int
XK_ISO_Fast_Cursor_Down: int
XK_ISO_Continuous_Underline: int
XK_ISO_Discontinuous_Underline: int
XK_ISO_Emphasize: int
XK_ISO_Center_Object: int
XK_ISO_Enter: int
XK_dead_grave: int
XK_dead_acute: int
XK_dead_circumflex: int
XK_dead_tilde: int
XK_dead_macron: int
XK_dead_breve: int
XK_dead_abovedot: int
XK_dead_diaeresis: int
XK_dead_abovering: int
XK_dead_doubleacute: int
XK_dead_caron: int
XK_dead_cedilla: int
XK_dead_ogonek: int
XK_dead_iota: int
XK_dead_voiced_sound: int
XK_dead_semivoiced_sound: int
XK_dead_belowdot: int
XK_First_Virtual_Screen: int
XK_Prev_Virtual_Screen: int
XK_Next_Virtual_Screen: int
XK_Last_Virtual_Screen: int
XK_Terminate_Server: int
XK_AccessX_Enable: int
XK_AccessX_Feedback_Enable: int
XK_RepeatKeys_Enable: int
XK_SlowKeys_Enable: int
XK_BounceKeys_Enable: int
XK_StickyKeys_Enable: int
XK_MouseKeys_Enable: int
XK_MouseKeys_Accel_Enable: int
XK_Overlay1_Enable: int
XK_Overlay2_Enable: int
XK_AudibleBell_Enable: int
XK_Pointer_Left: int
XK_Pointer_Right: int
XK_Pointer_Up: int
XK_Pointer_Down: int
XK_Pointer_UpLeft: int
XK_Pointer_UpRight: int
XK_Pointer_DownLeft: int
XK_Pointer_DownRight: int
XK_Pointer_Button_Dflt: int
XK_Pointer_Button1: int
XK_Pointer_Button2: int
XK_Pointer_Button3: int
XK_Pointer_Button4: int
XK_Pointer_Button5: int
XK_Pointer_DblClick_Dflt: int
XK_Pointer_DblClick1: int
XK_Pointer_DblClick2: int
XK_Pointer_DblClick3: int
XK_Pointer_DblClick4: int
XK_Pointer_DblClick5: int
XK_Pointer_Drag_Dflt: int
XK_Pointer_Drag1: int
XK_Pointer_Drag2: int
XK_Pointer_Drag3: int
XK_Pointer_Drag4: int
XK_Pointer_Drag5: int
XK_Pointer_EnableKeys: int
XK_Pointer_Accelerate: int
XK_Pointer_DfltBtnNext: int
XK_Pointer_DfltBtnPrev: int



XK_BackSpace: int
XK_Tab: int
XK_Linefeed: int
XK_Clear: int
XK_Return: int
XK_Pause: int
XK_Scroll_Lock: int
XK_Sys_Req: int
XK_Escape: int
XK_Delete: int
XK_Multi_key: int
XK_SingleCandidate: int
XK_MultipleCandidate: int
XK_PreviousCandidate: int
XK_Kanji: int
XK_Muhenkan: int
XK_Henkan_Mode: int
XK_Henkan: int
XK_Romaji: int
XK_Hiragana: int
XK_Katakana: int
XK_Hiragana_Katakana: int
XK_Zenkaku: int
XK_Hankaku: int
XK_Zenkaku_Hankaku: int
XK_Touroku: int
XK_Massyo: int
XK_Kana_Lock: int
XK_Kana_Shift: int
XK_Eisu_Shift: int
XK_Eisu_toggle: int
XK_Zen_Koho: int
XK_Mae_Koho: int
XK_Home: int
XK_Left: int
XK_Up: int
XK_Right: int
XK_Down: int
XK_Prior: int
XK_Page_Up: int
XK_Next: int
XK_Page_Down: int
XK_End: int
XK_Begin: int
XK_Select: int
XK_Print: int
XK_Execute: int
XK_Insert: int
XK_Undo: int
XK_Redo: int
XK_Menu: int
XK_Find: int
XK_Cancel: int
XK_Help: int
XK_Break: int
XK_Mode_switch: int
XK_script_switch: int
XK_Num_Lock: int
XK_KP_Space: int
XK_KP_Tab: int
XK_KP_Enter: int
XK_KP_F1: int
XK_KP_F2: int
XK_KP_F3: int
XK_KP_F4: int
XK_KP_Home: int
XK_KP_Left: int
XK_KP_Up: int
XK_KP_Right: int
XK_KP_Down: int
XK_KP_Prior: int
XK_KP_Page_Up: int
XK_KP_Next: int
XK_KP_Page_Down: int
XK_KP_End: int
XK_KP_Begin: int
XK_KP_Insert: int
XK_KP_Delete: int
XK_KP_Equal: int
XK_KP_Multiply: int
XK_KP_Add: int
XK_KP_Separator: int
XK_KP_Subtract: int
XK_KP_Decimal: int
XK_KP_Divide: int
XK_KP_0: int
XK_KP_1: int
XK_KP_2: int
XK_KP_3: int
XK_KP_4: int
XK_KP_5: int
XK_KP_6: int
XK_KP_7: int
XK_KP_8: int
XK_KP_9: int
XK_F1: int
XK_F2: int
XK_F3: int
XK_F4: int
XK_F5: int
XK_F6: int
XK_F7: int
XK_F8: int
XK_F9: int
XK_F10: int
XK_F11: int
XK_L1: int
XK_F12: int
XK_L2: int
XK_F13: int
XK_L3: int
XK_F14: int
XK_L4: int
XK_F15: int
XK_L5: int
XK_F16: int
XK_L6: int
XK_F17: int
XK_L7: int
XK_F18: int
XK_L8: int
XK_F19: int
XK_L9: int
XK_F20: int
XK_L10: int
XK_F21: int
XK_R1: int
XK_F22: int
XK_R2: int
XK_F23: int
XK_R3: int
XK_F24: int
XK_R4: int
XK_F25: int
XK_R5: int
XK_F26: int
XK_R6: int
XK_F27: int
XK_R7: int
XK_F28: int
XK_R8: int
XK_F29: int
XK_R9: int
XK_F30: int
XK_R10: int
XK_F31: int
XK_R11: int
XK_F32: int
XK_R12: int
XK_F33: int
XK_R13: int
XK_F34: int
XK_R14: int
XK_F35: int
XK_R15: int
XK_Shift_L: int
XK_Shift_R: int
XK_Control_L: int
XK_Control_R: int
XK_Caps_Lock: int
XK_Shift_Lock: int
XK_Meta_L: int
XK_Meta_R: int
XK_Alt_L: int
XK_Alt_R: int
XK_Super_L: int
XK_Super_R: int
XK_Hyper_L: int
XK_Hyper_R: int



XK_Greek_ALPHAaccent: int
XK_Greek_EPSILONaccent: int
XK_Greek_ETAaccent: int
XK_Greek_IOTAaccent: int
XK_Greek_IOTAdiaeresis: int
XK_Greek_OMICRONaccent: int
XK_Greek_UPSILONaccent: int
XK_Greek_UPSILONdieresis: int
XK_Greek_OMEGAaccent: int
XK_Greek_accentdieresis: int
XK_Greek_horizbar: int
XK_Greek_alphaaccent: int
XK_Greek_epsilonaccent: int
XK_Greek_etaaccent: int
XK_Greek_iotaaccent: int
XK_Greek_iotadieresis: int
XK_Greek_iotaaccentdieresis: int
XK_Greek_omicronaccent: int
XK_Greek_upsilonaccent: int
XK_Greek_upsilondieresis: int
XK_Greek_upsilonaccentdieresis: int
XK_Greek_omegaaccent: int
XK_Greek_ALPHA: int
XK_Greek_BETA: int
XK_Greek_GAMMA: int
XK_Greek_DELTA: int
XK_Greek_EPSILON: int
XK_Greek_ZETA: int
XK_Greek_ETA: int
XK_Greek_THETA: int
XK_Greek_IOTA: int
XK_Greek_KAPPA: int
XK_Greek_LAMDA: int
XK_Greek_LAMBDA: int
XK_Greek_MU: int
XK_Greek_NU: int
XK_Greek_XI: int
XK_Greek_OMICRON: int
XK_Greek_PI: int
XK_Greek_RHO: int
XK_Greek_SIGMA: int
XK_Greek_TAU: int
XK_Greek_UPSILON: int
XK_Greek_PHI: int
XK_Greek_CHI: int
XK_Greek_PSI: int
XK_Greek_OMEGA: int
XK_Greek_alpha: int
XK_Greek_beta: int
XK_Greek_gamma: int
XK_Greek_delta: int
XK_Greek_epsilon: int
XK_Greek_zeta: int
XK_Greek_eta: int
XK_Greek_theta: int
XK_Greek_iota: int
XK_Greek_kappa: int
XK_Greek_lamda: int
XK_Greek_lambda: int
XK_Greek_mu: int
XK_Greek_nu: int
XK_Greek_xi: int
XK_Greek_omicron: int
XK_Greek_pi: int
XK_Greek_rho: int
XK_Greek_sigma: int
XK_Greek_finalsmallsigma: int
XK_Greek_tau: int
XK_Greek_upsilon: int
XK_Greek_phi: int
XK_Greek_chi: int
XK_Greek_psi: int
XK_Greek_omega: int
XK_Greek_switch: int



from typing_extensions import TypeAlias

from Xlib.protocol import rq

class AnyEvent(rq.Event): ...
class KeyButtonPointer(rq.Event): ...
class KeyPress(KeyButtonPointer): ...
class KeyRelease(KeyButtonPointer): ...
class ButtonPress(KeyButtonPointer): ...
class ButtonRelease(KeyButtonPointer): ...
class MotionNotify(KeyButtonPointer): ...
class EnterLeave(rq.Event): ...
class EnterNotify(EnterLeave): ...
class LeaveNotify(EnterLeave): ...
class Focus(rq.Event): ...
class FocusIn(Focus): ...
class FocusOut(Focus): ...
class Expose(rq.Event): ...
class GraphicsExpose(rq.Event): ...
class NoExpose(rq.Event): ...
class VisibilityNotify(rq.Event): ...
class CreateNotify(rq.Event): ...
class DestroyNotify(rq.Event): ...
class UnmapNotify(rq.Event): ...
class MapNotify(rq.Event): ...
class MapRequest(rq.Event): ...
class ReparentNotify(rq.Event): ...
class ConfigureNotify(rq.Event): ...
class ConfigureRequest(rq.Event): ...
class GravityNotify(rq.Event): ...
class ResizeRequest(rq.Event): ...
class Circulate(rq.Event): ...
class CirculateNotify(Circulate): ...
class CirculateRequest(Circulate): ...
class PropertyNotify(rq.Event): ...
class SelectionClear(rq.Event): ...
class SelectionRequest(rq.Event): ...
class SelectionNotify(rq.Event): ...
class ColormapNotify(rq.Event): ...
class MappingNotify(rq.Event): ...
class ClientMessage(rq.Event): ...
class KeymapNotify(rq.Event): ...

_EventClass: TypeAlias = dict[
    int,
    type[KeyPress]
    | type[KeyRelease]
    | type[ButtonPress]
    | type[ButtonRelease]
    | type[MotionNotify]
    | type[EnterNotify]
    | type[LeaveNotify]
    | type[FocusIn]
    | type[FocusOut]
    | type[KeymapNotify]
    | type[Expose]
    | type[GraphicsExpose]
    | type[NoExpose]
    | type[VisibilityNotify]
    | type[CreateNotify]
    | type[DestroyNotify]
    | type[UnmapNotify]
    | type[MapNotify]
    | type[MapRequest]
    | type[ReparentNotify]
    | type[ConfigureNotify]
    | type[ConfigureRequest]
    | type[GravityNotify]
    | type[ResizeRequest]
    | type[CirculateNotify]
    | type[CirculateRequest]
    | type[PropertyNotify]
    | type[SelectionClear]
    | type[SelectionRequest]
    | type[SelectionNotify]
    | type[ColormapNotify]
    | type[ClientMessage]
    | type[MappingNotify],
]
event_class: _EventClass



XK_Aogonek: int
XK_breve: int
XK_Lstroke: int
XK_Lcaron: int
XK_Sacute: int
XK_Scaron: int
XK_Scedilla: int
XK_Tcaron: int
XK_Zacute: int
XK_Zcaron: int
XK_Zabovedot: int
XK_aogonek: int
XK_ogonek: int
XK_lstroke: int
XK_lcaron: int
XK_sacute: int
XK_caron: int
XK_scaron: int
XK_scedilla: int
XK_tcaron: int
XK_zacute: int
XK_doubleacute: int
XK_zcaron: int
XK_zabovedot: int
XK_Racute: int
XK_Abreve: int
XK_Lacute: int
XK_Cacute: int
XK_Ccaron: int
XK_Eogonek: int
XK_Ecaron: int
XK_Dcaron: int
XK_Dstroke: int
XK_Nacute: int
XK_Ncaron: int
XK_Odoubleacute: int
XK_Rcaron: int
XK_Uring: int
XK_Udoubleacute: int
XK_Tcedilla: int
XK_racute: int
XK_abreve: int
XK_lacute: int
XK_cacute: int
XK_ccaron: int
XK_eogonek: int
XK_ecaron: int
XK_dcaron: int
XK_dstroke: int
XK_nacute: int
XK_ncaron: int
XK_odoubleacute: int
XK_udoubleacute: int
XK_rcaron: int
XK_uring: int
XK_tcedilla: int
XK_abovedot: int



XK_Hstroke: int
XK_Hcircumflex: int
XK_Iabovedot: int
XK_Gbreve: int
XK_Jcircumflex: int
XK_hstroke: int
XK_hcircumflex: int
XK_idotless: int
XK_gbreve: int
XK_jcircumflex: int
XK_Cabovedot: int
XK_Ccircumflex: int
XK_Gabovedot: int
XK_Gcircumflex: int
XK_Ubreve: int
XK_Scircumflex: int
XK_cabovedot: int
XK_ccircumflex: int
XK_gabovedot: int
XK_gcircumflex: int
XK_ubreve: int
XK_scircumflex: int



from _typeshed import ReadableBuffer, SliceableBuffer
from collections.abc import Iterable, Sequence
from typing import SupportsFloat, TypeVar
from typing_extensions import SupportsIndex, TypeAlias

from Xlib._typing import Unused
from Xlib.display import Display
from Xlib.protocol import display, request, rq
from Xlib.xobject import drawable, resource

_T = TypeVar("_T")
_Floatable: TypeAlias = SupportsFloat | SupportsIndex | str | ReadableBuffer

extname: str
PropertyDeleted: int
PropertyCreated: int
PropertyModified: int
NotifyNormal: int
NotifyGrab: int
NotifyUngrab: int
NotifyWhileGrabbed: int
NotifyPassiveGrab: int
NotifyPassiveUngrab: int
NotifyAncestor: int
NotifyVirtual: int
NotifyInferior: int
NotifyNonlinear: int
NotifyNonlinearVirtual: int
NotifyPointer: int
NotifyPointerRoot: int
NotifyDetailNone: int
GrabtypeButton: int
GrabtypeKeycode: int
GrabtypeEnter: int
GrabtypeFocusIn: int
GrabtypeTouchBegin: int
AnyModifier: int
AnyButton: int
AnyKeycode: int
AsyncDevice: int
SyncDevice: int
ReplayDevice: int
AsyncPairedDevice: int
AsyncPair: int
SyncPair: int
SlaveSwitch: int
DeviceChange: int
MasterAdded: int
MasterRemoved: int
SlaveAdded: int
SlaveRemoved: int
SlaveAttached: int
SlaveDetached: int
DeviceEnabled: int
DeviceDisabled: int
AddMaster: int
RemoveMaster: int
AttachSlave: int
DetachSlave: int
AttachToMaster: int
Floating: int
ModeRelative: int
ModeAbsolute: int
MasterPointer: int
MasterKeyboard: int
SlavePointer: int
SlaveKeyboard: int
FloatingSlave: int
KeyClass: int
ButtonClass: int
ValuatorClass: int
ScrollClass: int
TouchClass: int
KeyRepeat: int
AllDevices: int
AllMasterDevices: int
DeviceChanged: int
KeyPress: int
KeyRelease: int
ButtonPress: int
ButtonRelease: int
Motion: int
Enter: int
Leave: int
FocusIn: int
FocusOut: int
HierarchyChanged: int
PropertyEvent: int
RawKeyPress: int
RawKeyRelease: int
RawButtonPress: int
RawButtonRelease: int
RawMotion: int
DeviceChangedMask: int
KeyPressMask: int
KeyReleaseMask: int
ButtonPressMask: int
ButtonReleaseMask: int
MotionMask: int
EnterMask: int
LeaveMask: int
FocusInMask: int
FocusOutMask: int
HierarchyChangedMask: int
PropertyEventMask: int
RawKeyPressMask: int
RawKeyReleaseMask: int
RawButtonPressMask: int
RawButtonReleaseMask: int
RawMotionMask: int
GrabModeSync: int
GrabModeAsync: int
GrabModeTouch: int
DEVICEID = rq.Card16
DEVICE = rq.Card16
DEVICEUSE = rq.Card8
PROPERTY_TYPE_FLOAT: str

# ignore[override] because of Liskov substitution principle violations
class FP1616(rq.Int32):
    def check_value(self, value: float) -> int: ...  # type: ignore[override]
    def parse_value(self, value: _Floatable, display: Unused) -> float: ...  # type: ignore[override]

class FP3232(rq.ValueField):
    structcode: str
    def check_value(self, value: _T) -> _T: ...  # type: ignore[override]
    def parse_value(self, value: tuple[_Floatable, _Floatable], display: Unused) -> float: ...  # type: ignore[override]

class XIQueryVersion(rq.ReplyRequest): ...

def query_version(self: Display | resource.Resource) -> XIQueryVersion: ...

class Mask(rq.List):
    def __init__(self, name: str) -> None: ...
    def pack_value(self, val: int | Iterable[int]) -> tuple[bytes, int, None]: ...  # type: ignore[override]

EventMask: rq.Struct

class XISelectEvents(rq.Request): ...

def select_events(self: drawable.Window, event_masks: Sequence[tuple[int, Sequence[int]]]) -> XISelectEvents: ...

AnyInfo: rq.Struct

class ButtonMask:
    def __init__(self, value: int, length: int) -> None: ...
    def __getitem__(self, key: int) -> int: ...
    def __len__(self) -> int: ...

class ButtonState(rq.ValueField):
    structcode: None
    def __init__(self, name: str) -> None: ...
    def parse_binary_value(  # type: ignore[override]  # length: None will error. See: https://github.com/python-xlib/python-xlib/pull/248
        self, data: SliceableBuffer, display: Unused, length: int, fmt: Unused
    ) -> tuple[ButtonMask, SliceableBuffer]: ...

ButtonInfo: rq.Struct
KeyInfo: rq.Struct
ValuatorInfo: rq.Struct
ScrollInfo: rq.Struct
TouchInfo: rq.Struct
INFO_CLASSES: dict[int, rq.Struct]

class ClassInfoClass:
    structcode: None
    def parse_binary(self, data: SliceableBuffer, display: display.Display | None) -> tuple[rq.DictWrapper, SliceableBuffer]: ...

ClassInfo: ClassInfoClass
DeviceInfo: rq.Struct

class XIQueryDevice(rq.ReplyRequest): ...

def query_device(self: Display | resource.Resource, deviceid: int) -> XIQueryDevice: ...

class XIListProperties(rq.ReplyRequest): ...

def list_device_properties(self: Display | resource.Resource, deviceid: int) -> XIListProperties: ...

class XIGetProperty(rq.ReplyRequest): ...

def get_device_property(
    self: Display | resource.Resource, deviceid: int, property: int, type: int, offset: int, length: int, delete: int = ...
) -> XIGetProperty: ...

class XIChangeProperty(rq.Request): ...

def change_device_property(
    self: Display | resource.Resource, deviceid: int, property: int, type: int, mode: int, value: Sequence[float] | Sequence[str]
) -> XIChangeProperty: ...

class XIDeleteProperty(rq.Request): ...

def delete_device_property(self: Display | resource.Resource, deviceid: int, property: int) -> XIDeleteProperty: ...

class XIGrabDevice(rq.ReplyRequest): ...

def grab_device(
    self: drawable.Window,
    deviceid: int,
    time: int,
    grab_mode: int,
    paired_device_mode: int,
    owner_events: bool,
    event_mask: Sequence[int],
) -> XIGrabDevice: ...

class XIUngrabDevice(rq.Request): ...

def ungrab_device(self: Display | resource.Resource, deviceid: int, time: int) -> XIUngrabDevice: ...

class XIPassiveGrabDevice(rq.ReplyRequest): ...

def passive_grab_device(
    self: drawable.Window,
    deviceid: int,
    time: int,
    detail: int,
    grab_type: int,
    grab_mode: int,
    paired_device_mode: int,
    owner_events: bool,
    event_mask: Sequence[int],
    modifiers: Sequence[int],
) -> XIPassiveGrabDevice: ...
def grab_keycode(
    self: drawable.Window,
    deviceid: int,
    time: int,
    keycode: int,
    grab_mode: int,
    paired_device_mode: int,
    owner_events: bool,
    event_mask: Sequence[int],
    modifiers: Sequence[int],
) -> XIPassiveGrabDevice: ...

class XIPassiveUngrabDevice(rq.Request): ...

def passive_ungrab_device(
    self: drawable.Window, deviceid: int, detail: int, grab_type: int, modifiers: Sequence[int]
) -> XIPassiveUngrabDevice: ...
def ungrab_keycode(self: drawable.Window, deviceid: int, keycode: int, modifiers: Sequence[int]) -> XIPassiveUngrabDevice: ...

HierarchyInfo: rq.Struct
HierarchyEventData: rq.Struct
ModifierInfo: rq.Struct
GroupInfo: rq.Struct
DeviceEventData: rq.Struct
DeviceChangedEventData: rq.Struct
PropertyEventData: rq.Struct

def init(disp: Display, info: request.QueryExtension) -> None: ...



from Xlib._typing import ErrorHandler
from Xlib.display import Display
from Xlib.protocol import request, rq
from Xlib.xobject import drawable

extname: str
NotifyMask: int
CycleMask: int
StateOff: int
StateOn: int
StateCycle: int
KindBlanked: int
KindInternal: int
KindExternal: int

class QueryVersion(rq.ReplyRequest): ...

def query_version(self: drawable.Drawable) -> QueryVersion: ...

class QueryInfo(rq.ReplyRequest): ...

def query_info(self: drawable.Drawable) -> QueryInfo: ...

class SelectInput(rq.Request): ...

def select_input(self: drawable.Drawable, mask: int) -> SelectInput: ...

class SetAttributes(rq.Request): ...

def set_attributes(
    self: drawable.Drawable,
    x: int,
    y: int,
    width: int,
    height: int,
    border_width: int,
    window_class: int = ...,
    depth: int = ...,
    visual: int = ...,
    onerror: ErrorHandler[object] | None = ...,
    **keys: object,
) -> SetAttributes: ...

class UnsetAttributes(rq.Request): ...

def unset_attributes(self: drawable.Drawable, onerror: ErrorHandler[object] | None = ...) -> UnsetAttributes: ...

class Notify(rq.Event): ...

def init(disp: Display, info: request.QueryExtension) -> None: ...



from Xlib._typing import Unused
from Xlib.display import Display
from Xlib.protocol import rq
from Xlib.xobject import resource

extname: str
CurrentCursor: int

class GetVersion(rq.ReplyRequest): ...

def get_version(self: Display | resource.Resource, major: int, minor: int) -> GetVersion: ...

class CompareCursor(rq.ReplyRequest): ...

def compare_cursor(self: Display | resource.Resource, cursor: int) -> int: ...

class FakeInput(rq.Request): ...

def fake_input(
    self: Display | resource.Resource,
    event_type: int,
    detail: int = ...,
    time: int = ...,
    root: int = ...,
    x: int = ...,
    y: int = ...,
) -> None: ...

class GrabControl(rq.Request): ...

def grab_control(self: Display | resource.Resource, impervious: bool) -> None: ...
def init(disp: Display, info: Unused) -> None: ...



from Xlib._typing import OpenFile

FamilyInternet: int
FamilyDECnet: int
FamilyChaos: int
FamilyServerInterpreted: int
FamilyInternetV6: int
FamilyLocal: int

class Xauthority:
    entries: list[tuple[bytes, bytes, bytes, bytes, bytes]]
    def __init__(self, filename: OpenFile | None = ...) -> None: ...
    def __len__(self) -> int: ...
    def __getitem__(self, i: int) -> tuple[bytes, bytes, bytes, bytes, bytes]: ...
    def get_best_auth(
        self, family: bytes, address: bytes, dispno: bytes, types: tuple[bytes, ...] = ...
    ) -> tuple[bytes, bytes]: ...



from Xlib._typing import Unused
from Xlib.display import Display
from Xlib.protocol import rq
from Xlib.xobject import resource

extname: str

def query_target_count(self: Display | resource.Resource, target: Target) -> int: ...
def query_int_attribute(self: Display | resource.Resource, target: Target, display_mask: int, attr: int) -> int | None: ...
def set_int_attribute(self: Display | resource.Resource, target: Target, display_mask: int, attr: int, value: int) -> bool: ...
def query_string_attribute(self: Display | resource.Resource, target: Target, display_mask: int, attr: int) -> str | None: ...
def query_valid_attr_values(
    self: Display | resource.Resource, target: Target, display_mask: int, attr: int
) -> tuple[int, int] | None: ...
def query_binary_data(self: Display | resource.Resource, target: Target, display_mask: int, attr: int) -> bytes | None: ...
def get_coolers_used_by_gpu(self: Display | resource.Resource, target: Target) -> list[int] | None: ...
def get_gpu_count(self: Display | resource.Resource) -> int: ...
def get_name(self: Display | resource.Resource, target: Target) -> str | None: ...
def get_driver_version(self: Display | resource.Resource, target: Target) -> str | None: ...
def get_vbios_version(self: Display | resource.Resource, target: Target) -> str | None: ...
def get_gpu_uuid(self: Display | resource.Resource, target: Target) -> str | None: ...
def get_utilization_rates(self: Display | resource.Resource, target: Target) -> dict[str, str | int]: ...
def get_performance_modes(self: Display | resource.Resource, target: Target) -> list[dict[str, str | int]]: ...
def get_clock_info(self: Display | resource.Resource, target: Target) -> dict[str, str | int]: ...
def get_vram(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_irq(self: Display | resource.Resource, target: Target) -> int | None: ...
def supports_framelock(self: Display | resource.Resource, target: Target) -> int | None: ...
def gvo_supported(self: Display | resource.Resource, screen: Target) -> int | None: ...
def get_core_temp(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_core_threshold(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_default_core_threshold(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_max_core_threshold(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_ambient_temp(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_cuda_cores(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_memory_bus_width(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_total_dedicated_gpu_memory(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_used_dedicated_gpu_memory(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_curr_pcie_link_width(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_max_pcie_link_width(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_curr_pcie_link_generation(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_encoder_utilization(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_decoder_utilization(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_current_performance_level(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_gpu_nvclock_offset(self: Display | resource.Resource, target: Target, perf_level: int) -> int | None: ...
def set_gpu_nvclock_offset(self: Display | resource.Resource, target: Target, perf_level: int, offset: int) -> bool: ...
def set_gpu_nvclock_offset_all_levels(self: Display | resource.Resource, target: Target, offset: int) -> bool: ...
def get_gpu_nvclock_offset_range(
    self: Display | resource.Resource, target: Target, perf_level: int
) -> tuple[int, int] | None: ...
def get_mem_transfer_rate_offset(self: Display | resource.Resource, target: Target, perf_level: int) -> int | None: ...
def set_mem_transfer_rate_offset(self: Display | resource.Resource, target: Target, perf_level: int, offset: int) -> bool: ...
def set_mem_transfer_rate_offset_all_levels(self: Display | resource.Resource, target: Target, offset: int) -> bool: ...
def get_mem_transfer_rate_offset_range(
    self: Display | resource.Resource, target: Target, perf_level: int
) -> tuple[int, int] | None: ...
def get_cooler_manual_control_enabled(self: Display | resource.Resource, target: Target) -> int | None: ...
def set_cooler_manual_control_enabled(self: Display | resource.Resource, target: Target, enabled: bool) -> bool: ...
def get_fan_duty(self: Display | resource.Resource, target: Target) -> int | None: ...
def set_fan_duty(self: Display | resource.Resource, cooler: Target, speed: int) -> bool: ...
def get_fan_rpm(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_max_displays(self: Display | resource.Resource, target: Target) -> int | None: ...
def init(disp: Display, info: Unused) -> None: ...

NV_CTRL_FLATPANEL_SCALING: int
NV_CTRL_FLATPANEL_SCALING_DEFAULT: int
NV_CTRL_FLATPANEL_SCALING_NATIVE: int
NV_CTRL_FLATPANEL_SCALING_SCALED: int
NV_CTRL_FLATPANEL_SCALING_CENTERED: int
NV_CTRL_FLATPANEL_SCALING_ASPECT_SCALED: int
NV_CTRL_FLATPANEL_DITHERING: int
NV_CTRL_FLATPANEL_DITHERING_DEFAULT: int
NV_CTRL_FLATPANEL_DITHERING_ENABLED: int
NV_CTRL_FLATPANEL_DITHERING_DISABLED: int
NV_CTRL_DITHERING: int
NV_CTRL_DITHERING_AUTO: int
NV_CTRL_DITHERING_ENABLED: int
NV_CTRL_DITHERING_DISABLED: int
NV_CTRL_DIGITAL_VIBRANCE: int
NV_CTRL_BUS_TYPE: int
NV_CTRL_BUS_TYPE_AGP: int
NV_CTRL_BUS_TYPE_PCI: int
NV_CTRL_BUS_TYPE_PCI_EXPRESS: int
NV_CTRL_BUS_TYPE_INTEGRATED: int
NV_CTRL_TOTAL_GPU_MEMORY: int
NV_CTRL_VIDEO_RAM: int
NV_CTRL_IRQ: int
NV_CTRL_OPERATING_SYSTEM: int
NV_CTRL_OPERATING_SYSTEM_LINUX: int
NV_CTRL_OPERATING_SYSTEM_FREEBSD: int
NV_CTRL_OPERATING_SYSTEM_SUNOS: int
NV_CTRL_SYNC_TO_VBLANK: int
NV_CTRL_SYNC_TO_VBLANK_OFF: int
NV_CTRL_SYNC_TO_VBLANK_ON: int
NV_CTRL_LOG_ANISO: int
NV_CTRL_FSAA_MODE: int
NV_CTRL_FSAA_MODE_NONE: int
NV_CTRL_FSAA_MODE_2x: int
NV_CTRL_FSAA_MODE_2x_5t: int
NV_CTRL_FSAA_MODE_15x15: int
NV_CTRL_FSAA_MODE_2x2: int
NV_CTRL_FSAA_MODE_4x: int
NV_CTRL_FSAA_MODE_4x_9t: int
NV_CTRL_FSAA_MODE_8x: int
NV_CTRL_FSAA_MODE_16x: int
NV_CTRL_FSAA_MODE_8xS: int
NV_CTRL_FSAA_MODE_8xQ: int
NV_CTRL_FSAA_MODE_16xS: int
NV_CTRL_FSAA_MODE_16xQ: int
NV_CTRL_FSAA_MODE_32xS: int
NV_CTRL_FSAA_MODE_32x: int
NV_CTRL_FSAA_MODE_64xS: int
NV_CTRL_FSAA_MODE_MAX: int
NV_CTRL_UBB: int
NV_CTRL_UBB_OFF: int
NV_CTRL_UBB_ON: int
NV_CTRL_OVERLAY: int
NV_CTRL_OVERLAY_OFF: int
NV_CTRL_OVERLAY_ON: int
NV_CTRL_STEREO: int
NV_CTRL_STEREO_OFF: int
NV_CTRL_STEREO_DDC: int
NV_CTRL_STEREO_BLUELINE: int
NV_CTRL_STEREO_DIN: int
NV_CTRL_STEREO_PASSIVE_EYE_PER_DPY: int
NV_CTRL_STEREO_VERTICAL_INTERLACED: int
NV_CTRL_STEREO_COLOR_INTERLACED: int
NV_CTRL_STEREO_HORIZONTAL_INTERLACED: int
NV_CTRL_STEREO_CHECKERBOARD_PATTERN: int
NV_CTRL_STEREO_INVERSE_CHECKERBOARD_PATTERN: int
NV_CTRL_STEREO_3D_VISION: int
NV_CTRL_STEREO_3D_VISION_PRO: int
NV_CTRL_STEREO_HDMI_3D: int
NV_CTRL_STEREO_TRIDELITY_SL: int
NV_CTRL_STEREO_INBAND_STEREO_SIGNALING: int
NV_CTRL_STEREO_MAX: int
NV_CTRL_EMULATE: int
NV_CTRL_EMULATE_NONE: int
NV_CTRL_TWINVIEW: int
NV_CTRL_TWINVIEW_NOT_ENABLED: int
NV_CTRL_TWINVIEW_ENABLED: int
NV_CTRL_CONNECTED_DISPLAYS: int
NV_CTRL_ENABLED_DISPLAYS: int
NV_CTRL_FRAMELOCK: int
NV_CTRL_FRAMELOCK_NOT_SUPPORTED: int
NV_CTRL_FRAMELOCK_SUPPORTED: int
NV_CTRL_FRAMELOCK_MASTER: int
NV_CTRL_FRAMELOCK_MASTER_FALSE: int
NV_CTRL_FRAMELOCK_MASTER_TRUE: int
NV_CTRL_FRAMELOCK_POLARITY: int
NV_CTRL_FRAMELOCK_POLARITY_RISING_EDGE: int
NV_CTRL_FRAMELOCK_POLARITY_FALLING_EDGE: int
NV_CTRL_FRAMELOCK_POLARITY_BOTH_EDGES: int
NV_CTRL_FRAMELOCK_SYNC_DELAY: int
NV_CTRL_FRAMELOCK_SYNC_DELAY_MAX: int
NV_CTRL_FRAMELOCK_SYNC_DELAY_FACTOR: float
NV_CTRL_FRAMELOCK_SYNC_INTERVAL: int
NV_CTRL_FRAMELOCK_PORT0_STATUS: int
NV_CTRL_FRAMELOCK_PORT0_STATUS_INPUT: int
NV_CTRL_FRAMELOCK_PORT0_STATUS_OUTPUT: int
NV_CTRL_FRAMELOCK_PORT1_STATUS: int
NV_CTRL_FRAMELOCK_PORT1_STATUS_INPUT: int
NV_CTRL_FRAMELOCK_PORT1_STATUS_OUTPUT: int
NV_CTRL_FRAMELOCK_HOUSE_STATUS: int
NV_CTRL_FRAMELOCK_HOUSE_STATUS_NOT_DETECTED: int
NV_CTRL_FRAMELOCK_HOUSE_STATUS_DETECTED: int
NV_CTRL_FRAMELOCK_SYNC: int
NV_CTRL_FRAMELOCK_SYNC_DISABLE: int
NV_CTRL_FRAMELOCK_SYNC_ENABLE: int
NV_CTRL_FRAMELOCK_SYNC_READY: int
NV_CTRL_FRAMELOCK_SYNC_READY_FALSE: int
NV_CTRL_FRAMELOCK_SYNC_READY_TRUE: int
NV_CTRL_FRAMELOCK_STEREO_SYNC: int
NV_CTRL_FRAMELOCK_STEREO_SYNC_FALSE: int
NV_CTRL_FRAMELOCK_STEREO_SYNC_TRUE: int
NV_CTRL_FRAMELOCK_TEST_SIGNAL: int
NV_CTRL_FRAMELOCK_TEST_SIGNAL_DISABLE: int
NV_CTRL_FRAMELOCK_TEST_SIGNAL_ENABLE: int
NV_CTRL_FRAMELOCK_ETHERNET_DETECTED: int
NV_CTRL_FRAMELOCK_ETHERNET_DETECTED_NONE: int
NV_CTRL_FRAMELOCK_ETHERNET_DETECTED_PORT0: int
NV_CTRL_FRAMELOCK_ETHERNET_DETECTED_PORT1: int
NV_CTRL_FRAMELOCK_VIDEO_MODE: int
NV_CTRL_FRAMELOCK_VIDEO_MODE_NONE: int
NV_CTRL_FRAMELOCK_VIDEO_MODE_TTL: int
NV_CTRL_FRAMELOCK_VIDEO_MODE_NTSCPALSECAM: int
NV_CTRL_FRAMELOCK_VIDEO_MODE_HDTV: int
NV_CTRL_FRAMELOCK_VIDEO_MODE_COMPOSITE_AUTO: int
NV_CTRL_FRAMELOCK_VIDEO_MODE_COMPOSITE_BI_LEVEL: int
NV_CTRL_FRAMELOCK_VIDEO_MODE_COMPOSITE_TRI_LEVEL: int
NV_CTRL_FRAMELOCK_SYNC_RATE: int
NV_CTRL_FORCE_GENERIC_CPU: int
NV_CTRL_FORCE_GENERIC_CPU_DISABLE: int
NV_CTRL_FORCE_GENERIC_CPU_ENABLE: int
NV_CTRL_OPENGL_AA_LINE_GAMMA: int
NV_CTRL_OPENGL_AA_LINE_GAMMA_DISABLE: int
NV_CTRL_OPENGL_AA_LINE_GAMMA_ENABLE: int
NV_CTRL_FRAMELOCK_TIMING: int
NV_CTRL_FRAMELOCK_TIMING_FALSE: int
NV_CTRL_FRAMELOCK_TIMING_TRUE: int
NV_CTRL_FLIPPING_ALLOWED: int
NV_CTRL_FLIPPING_ALLOWED_FALSE: int
NV_CTRL_FLIPPING_ALLOWED_TRUE: int
NV_CTRL_ARCHITECTURE: int
NV_CTRL_ARCHITECTURE_X86: int
NV_CTRL_ARCHITECTURE_X86_64: int
NV_CTRL_ARCHITECTURE_IA64: int
NV_CTRL_ARCHITECTURE_ARM: int
NV_CTRL_ARCHITECTURE_AARCH64: int
NV_CTRL_ARCHITECTURE_PPC64LE: int
NV_CTRL_TEXTURE_CLAMPING: int
NV_CTRL_TEXTURE_CLAMPING_EDGE: int
NV_CTRL_TEXTURE_CLAMPING_SPEC: int
NV_CTRL_CURSOR_SHADOW: int
NV_CTRL_CURSOR_SHADOW_DISABLE: int
NV_CTRL_CURSOR_SHADOW_ENABLE: int
NV_CTRL_CURSOR_SHADOW_ALPHA: int
NV_CTRL_CURSOR_SHADOW_RED: int
NV_CTRL_CURSOR_SHADOW_GREEN: int
NV_CTRL_CURSOR_SHADOW_BLUE: int
NV_CTRL_CURSOR_SHADOW_X_OFFSET: int
NV_CTRL_CURSOR_SHADOW_Y_OFFSET: int
NV_CTRL_FSAA_APPLICATION_CONTROLLED: int
NV_CTRL_FSAA_APPLICATION_CONTROLLED_ENABLED: int
NV_CTRL_FSAA_APPLICATION_CONTROLLED_DISABLED: int
NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED: int
NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED_ENABLED: int
NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED_DISABLED: int
NV_CTRL_IMAGE_SHARPENING: int
NV_CTRL_TV_OVERSCAN: int
NV_CTRL_TV_FLICKER_FILTER: int
NV_CTRL_TV_BRIGHTNESS: int
NV_CTRL_TV_HUE: int
NV_CTRL_TV_CONTRAST: int
NV_CTRL_TV_SATURATION: int
NV_CTRL_TV_RESET_SETTINGS: int
NV_CTRL_GPU_CORE_TEMPERATURE: int
NV_CTRL_GPU_CORE_THRESHOLD: int
NV_CTRL_GPU_DEFAULT_CORE_THRESHOLD: int
NV_CTRL_GPU_MAX_CORE_THRESHOLD: int
NV_CTRL_AMBIENT_TEMPERATURE: int
NV_CTRL_PBUFFER_SCANOUT_SUPPORTED: int
NV_CTRL_PBUFFER_SCANOUT_FALSE: int
NV_CTRL_PBUFFER_SCANOUT_TRUE: int
NV_CTRL_PBUFFER_SCANOUT_XID: int
NV_CTRL_GVO_SUPPORTED: int
NV_CTRL_GVO_SUPPORTED_FALSE: int
NV_CTRL_GVO_SUPPORTED_TRUE: int
NV_CTRL_GVO_SYNC_MODE: int
NV_CTRL_GVO_SYNC_MODE_FREE_RUNNING: int
NV_CTRL_GVO_SYNC_MODE_GENLOCK: int
NV_CTRL_GVO_SYNC_MODE_FRAMELOCK: int
NV_CTRL_GVO_SYNC_SOURCE: int
NV_CTRL_GVO_SYNC_SOURCE_COMPOSITE: int
NV_CTRL_GVO_SYNC_SOURCE_SDI: int
NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT: int
NV_CTRL_GVIO_VIDEO_FORMAT_NONE: int
NV_CTRL_GVIO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC: int
NV_CTRL_GVIO_VIDEO_FORMAT_576I_50_00_SMPTE259_PAL: int
NV_CTRL_GVIO_VIDEO_FORMAT_720P_59_94_SMPTE296: int
NV_CTRL_GVIO_VIDEO_FORMAT_720P_60_00_SMPTE296: int
NV_CTRL_GVIO_VIDEO_FORMAT_1035I_59_94_SMPTE260: int
NV_CTRL_GVIO_VIDEO_FORMAT_1035I_60_00_SMPTE260: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_50_00_SMPTE295: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_50_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_59_94_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_60_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_23_976_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_24_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_25_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_29_97_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_30_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_720P_50_00_SMPTE296: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_48_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_47_96_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_720P_30_00_SMPTE296: int
NV_CTRL_GVIO_VIDEO_FORMAT_720P_29_97_SMPTE296: int
NV_CTRL_GVIO_VIDEO_FORMAT_720P_25_00_SMPTE296: int
NV_CTRL_GVIO_VIDEO_FORMAT_720P_24_00_SMPTE296: int
NV_CTRL_GVIO_VIDEO_FORMAT_720P_23_98_SMPTE296: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_25_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_29_97_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_30_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_24_00_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_23_98_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_30_00_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_29_97_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_60_00_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_59_94_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_25_00_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_50_00_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_24_00_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_23_98_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_48_00_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_47_96_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_50_00_3G_LEVEL_A_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_59_94_3G_LEVEL_A_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_60_00_3G_LEVEL_A_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_60_00_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_60_00_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_60_00_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_50_00_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_50_00_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_50_00_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_30_00_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_30_00_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_25_00_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_25_00_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_24_00_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_24_00_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_48_00_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_48_00_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_59_94_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_59_94_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_59_94_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_29_97_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_29_97_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_23_98_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_23_98_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_47_96_3G_LEVEL_B_SMPTE274: int
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_47_96_3G_LEVEL_B_SMPTE372: int
NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT: int
NV_CTRL_GVO_VIDEO_FORMAT_NONE: int
NV_CTRL_GVO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC: int
NV_CTRL_GVO_VIDEO_FORMAT_576I_50_00_SMPTE259_PAL: int
NV_CTRL_GVO_VIDEO_FORMAT_720P_59_94_SMPTE296: int
NV_CTRL_GVO_VIDEO_FORMAT_720P_60_00_SMPTE296: int
NV_CTRL_GVO_VIDEO_FORMAT_1035I_59_94_SMPTE260: int
NV_CTRL_GVO_VIDEO_FORMAT_1035I_60_00_SMPTE260: int
NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE295: int
NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080I_59_94_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080I_60_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080P_23_976_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080P_24_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080P_25_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080P_29_97_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080P_30_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_720P_50_00_SMPTE296: int
NV_CTRL_GVO_VIDEO_FORMAT_1080I_48_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080I_47_96_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_720P_30_00_SMPTE296: int
NV_CTRL_GVO_VIDEO_FORMAT_720P_29_97_SMPTE296: int
NV_CTRL_GVO_VIDEO_FORMAT_720P_25_00_SMPTE296: int
NV_CTRL_GVO_VIDEO_FORMAT_720P_24_00_SMPTE296: int
NV_CTRL_GVO_VIDEO_FORMAT_720P_23_98_SMPTE296: int
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_25_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_29_97_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_30_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_24_00_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_23_98_SMPTE274: int
NV_CTRL_GVO_VIDEO_FORMAT_2048P_30_00_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048P_29_97_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048I_60_00_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048I_59_94_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048P_25_00_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048I_50_00_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048P_24_00_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048P_23_98_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048I_48_00_SMPTE372: int
NV_CTRL_GVO_VIDEO_FORMAT_2048I_47_96_SMPTE372: int
NV_CTRL_GVIO_DETECTED_VIDEO_FORMAT: int
NV_CTRL_GVO_INPUT_VIDEO_FORMAT: int
NV_CTRL_GVO_DATA_FORMAT: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB444: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8A8_TO_YCRCBA4444: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8Z10_TO_YCRCBZ4444: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB422: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8A8_TO_YCRCBA4224: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8Z10_TO_YCRCBZ4224: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_RGB444: int
NV_CTRL_GVO_DATA_FORMAT_X8X8X8_444_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8A8_TO_RGBA4444: int
NV_CTRL_GVO_DATA_FORMAT_X8X8X8A8_4444_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_R8G8B8Z10_TO_RGBZ4444: int
NV_CTRL_GVO_DATA_FORMAT_X8X8X8Z8_4444_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_Y10CR10CB10_TO_YCRCB444: int
NV_CTRL_GVO_DATA_FORMAT_X10X10X10_444_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_Y10CR8CB8_TO_YCRCB444: int
NV_CTRL_GVO_DATA_FORMAT_X10X8X8_444_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_Y10CR8CB8A10_TO_YCRCBA4444: int
NV_CTRL_GVO_DATA_FORMAT_X10X8X8A10_4444_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_Y10CR8CB8Z10_TO_YCRCBZ4444: int
NV_CTRL_GVO_DATA_FORMAT_X10X8X8Z10_4444_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_DUAL_R8G8B8_TO_DUAL_YCRCB422: int
NV_CTRL_GVO_DATA_FORMAT_DUAL_Y8CR8CB8_TO_DUAL_YCRCB422: int
NV_CTRL_GVO_DATA_FORMAT_DUAL_X8X8X8_TO_DUAL_422_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_R10G10B10_TO_YCRCB422: int
NV_CTRL_GVO_DATA_FORMAT_R10G10B10_TO_YCRCB444: int
NV_CTRL_GVO_DATA_FORMAT_Y12CR12CB12_TO_YCRCB444: int
NV_CTRL_GVO_DATA_FORMAT_X12X12X12_444_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_R12G12B12_TO_YCRCB444: int
NV_CTRL_GVO_DATA_FORMAT_X8X8X8_422_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_X8X8X8A8_4224_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_X8X8X8Z8_4224_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_X10X10X10_422_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_X10X8X8_422_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_X10X8X8A10_4224_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_X10X8X8Z10_4224_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_X12X12X12_422_PASSTHRU: int
NV_CTRL_GVO_DATA_FORMAT_R12G12B12_TO_YCRCB422: int
NV_CTRL_GVO_DISPLAY_X_SCREEN: int
NV_CTRL_GVO_DISPLAY_X_SCREEN_ENABLE: int
NV_CTRL_GVO_DISPLAY_X_SCREEN_DISABLE: int
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED: int
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED_FALSE: int
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED_TRUE: int
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE: int
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE_AUTO: int
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE_BI_LEVEL: int
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE_TRI_LEVEL: int
NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED: int
NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED_NONE: int
NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED_HD: int
NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED_SD: int
NV_CTRL_GVO_VIDEO_OUTPUTS: int
NV_CTRL_GVO_VIDEO_OUTPUTS_NONE: int
NV_CTRL_GVO_VIDEO_OUTPUTS_VIDEO1: int
NV_CTRL_GVO_VIDEO_OUTPUTS_VIDEO2: int
NV_CTRL_GVO_VIDEO_OUTPUTS_VIDEO_BOTH: int
NV_CTRL_GVO_FIRMWARE_VERSION: int
NV_CTRL_GVO_SYNC_DELAY_PIXELS: int
NV_CTRL_GVO_SYNC_DELAY_LINES: int
NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE: int
NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE_FALSE: int
NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE_TRUE: int
NV_CTRL_GVO_GLX_LOCKED: int
NV_CTRL_GVO_GLX_LOCKED_FALSE: int
NV_CTRL_GVO_GLX_LOCKED_TRUE: int
NV_CTRL_GVIO_VIDEO_FORMAT_WIDTH: int
NV_CTRL_GVIO_VIDEO_FORMAT_HEIGHT: int
NV_CTRL_GVIO_VIDEO_FORMAT_REFRESH_RATE: int
NV_CTRL_GVO_VIDEO_FORMAT_WIDTH: int
NV_CTRL_GVO_VIDEO_FORMAT_HEIGHT: int
NV_CTRL_GVO_VIDEO_FORMAT_REFRESH_RATE: int
NV_CTRL_GVO_X_SCREEN_PAN_X: int
NV_CTRL_GVO_X_SCREEN_PAN_Y: int
NV_CTRL_GPU_OVERCLOCKING_STATE: int
NV_CTRL_GPU_OVERCLOCKING_STATE_NONE: int
NV_CTRL_GPU_OVERCLOCKING_STATE_MANUAL: int
NV_CTRL_GPU_2D_CLOCK_FREQS: int
NV_CTRL_GPU_3D_CLOCK_FREQS: int
NV_CTRL_GPU_DEFAULT_2D_CLOCK_FREQS: int
NV_CTRL_GPU_DEFAULT_3D_CLOCK_FREQS: int
NV_CTRL_GPU_CURRENT_CLOCK_FREQS: int
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS: int
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_INVALID: int
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION: int
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_START: int
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_CANCEL: int
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE: int
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE_IDLE: int
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE_BUSY: int
NV_CTRL_FLATPANEL_CHIP_LOCATION: int
NV_CTRL_FLATPANEL_CHIP_LOCATION_INTERNAL: int
NV_CTRL_FLATPANEL_CHIP_LOCATION_EXTERNAL: int
NV_CTRL_FLATPANEL_LINK: int
NV_CTRL_FLATPANEL_LINK_SINGLE: int
NV_CTRL_FLATPANEL_LINK_DUAL: int
NV_CTRL_FLATPANEL_LINK_QUAD: int
NV_CTRL_FLATPANEL_SIGNAL: int
NV_CTRL_FLATPANEL_SIGNAL_LVDS: int
NV_CTRL_FLATPANEL_SIGNAL_TMDS: int
NV_CTRL_FLATPANEL_SIGNAL_DISPLAYPORT: int
NV_CTRL_USE_HOUSE_SYNC: int
NV_CTRL_USE_HOUSE_SYNC_DISABLED: int
NV_CTRL_USE_HOUSE_SYNC_INPUT: int
NV_CTRL_USE_HOUSE_SYNC_OUTPUT: int
NV_CTRL_USE_HOUSE_SYNC_FALSE: int
NV_CTRL_USE_HOUSE_SYNC_TRUE: int
NV_CTRL_EDID_AVAILABLE: int
NV_CTRL_EDID_AVAILABLE_FALSE: int
NV_CTRL_EDID_AVAILABLE_TRUE: int
NV_CTRL_FORCE_STEREO: int
NV_CTRL_FORCE_STEREO_FALSE: int
NV_CTRL_FORCE_STEREO_TRUE: int
NV_CTRL_IMAGE_SETTINGS: int
NV_CTRL_IMAGE_SETTINGS_HIGH_QUALITY: int
NV_CTRL_IMAGE_SETTINGS_QUALITY: int
NV_CTRL_IMAGE_SETTINGS_PERFORMANCE: int
NV_CTRL_IMAGE_SETTINGS_HIGH_PERFORMANCE: int
NV_CTRL_XINERAMA: int
NV_CTRL_XINERAMA_OFF: int
NV_CTRL_XINERAMA_ON: int
NV_CTRL_XINERAMA_STEREO: int
NV_CTRL_XINERAMA_STEREO_FALSE: int
NV_CTRL_XINERAMA_STEREO_TRUE: int
NV_CTRL_BUS_RATE: int
NV_CTRL_GPU_PCIE_MAX_LINK_WIDTH: int
NV_CTRL_SHOW_SLI_VISUAL_INDICATOR: int
NV_CTRL_SHOW_SLI_VISUAL_INDICATOR_FALSE: int
NV_CTRL_SHOW_SLI_VISUAL_INDICATOR_TRUE: int
NV_CTRL_SHOW_SLI_HUD: int
NV_CTRL_SHOW_SLI_HUD_FALSE: int
NV_CTRL_SHOW_SLI_HUD_TRUE: int
NV_CTRL_XV_SYNC_TO_DISPLAY: int
NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT2: int
NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT2: int
NV_CTRL_GVO_OVERRIDE_HW_CSC: int
NV_CTRL_GVO_OVERRIDE_HW_CSC_FALSE: int
NV_CTRL_GVO_OVERRIDE_HW_CSC_TRUE: int
NV_CTRL_GVO_CAPABILITIES: int
NV_CTRL_GVO_CAPABILITIES_APPLY_CSC_IMMEDIATELY: int
NV_CTRL_GVO_CAPABILITIES_APPLY_CSC_TO_X_SCREEN: int
NV_CTRL_GVO_CAPABILITIES_COMPOSITE_TERMINATION: int
NV_CTRL_GVO_CAPABILITIES_SHARED_SYNC_BNC: int
NV_CTRL_GVO_CAPABILITIES_MULTIRATE_SYNC: int
NV_CTRL_GVO_CAPABILITIES_ADVANCE_SYNC_SKEW: int
NV_CTRL_GVO_COMPOSITE_TERMINATION: int
NV_CTRL_GVO_COMPOSITE_TERMINATION_ENABLE: int
NV_CTRL_GVO_COMPOSITE_TERMINATION_DISABLE: int
NV_CTRL_ASSOCIATED_DISPLAY_DEVICES: int
NV_CTRL_FRAMELOCK_SLAVES: int
NV_CTRL_FRAMELOCK_MASTERABLE: int
NV_CTRL_PROBE_DISPLAYS: int
NV_CTRL_REFRESH_RATE: int
NV_CTRL_GVO_FLIP_QUEUE_SIZE: int
NV_CTRL_CURRENT_SCANLINE: int
NV_CTRL_INITIAL_PIXMAP_PLACEMENT: int
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_FORCE_SYSMEM: int
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_SYSMEM: int
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_VIDMEM: int
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_RESERVED: int
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_GPU_SYSMEM: int
NV_CTRL_PCI_BUS: int
NV_CTRL_PCI_DEVICE: int
NV_CTRL_PCI_FUNCTION: int
NV_CTRL_FRAMELOCK_FPGA_REVISION: int
NV_CTRL_MAX_SCREEN_WIDTH: int
NV_CTRL_MAX_SCREEN_HEIGHT: int
NV_CTRL_MAX_DISPLAYS: int
NV_CTRL_DYNAMIC_TWINVIEW: int
NV_CTRL_MULTIGPU_DISPLAY_OWNER: int
NV_CTRL_GPU_SCALING: int
NV_CTRL_GPU_SCALING_TARGET_INVALID: int
NV_CTRL_GPU_SCALING_TARGET_FLATPANEL_BEST_FIT: int
NV_CTRL_GPU_SCALING_TARGET_FLATPANEL_NATIVE: int
NV_CTRL_GPU_SCALING_METHOD_INVALID: int
NV_CTRL_GPU_SCALING_METHOD_STRETCHED: int
NV_CTRL_GPU_SCALING_METHOD_CENTERED: int
NV_CTRL_GPU_SCALING_METHOD_ASPECT_SCALED: int
NV_CTRL_FRONTEND_RESOLUTION: int
NV_CTRL_BACKEND_RESOLUTION: int
NV_CTRL_FLATPANEL_NATIVE_RESOLUTION: int
NV_CTRL_FLATPANEL_BEST_FIT_RESOLUTION: int
NV_CTRL_GPU_SCALING_ACTIVE: int
NV_CTRL_DFP_SCALING_ACTIVE: int
NV_CTRL_FSAA_APPLICATION_ENHANCED: int
NV_CTRL_FSAA_APPLICATION_ENHANCED_ENABLED: int
NV_CTRL_FSAA_APPLICATION_ENHANCED_DISABLED: int
NV_CTRL_FRAMELOCK_SYNC_RATE_4: int
NV_CTRL_GVO_LOCK_OWNER: int
NV_CTRL_GVO_LOCK_OWNER_NONE: int
NV_CTRL_GVO_LOCK_OWNER_GLX: int
NV_CTRL_GVO_LOCK_OWNER_CLONE: int
NV_CTRL_GVO_LOCK_OWNER_X_SCREEN: int
NV_CTRL_HWOVERLAY: int
NV_CTRL_HWOVERLAY_FALSE: int
NV_CTRL_HWOVERLAY_TRUE: int
NV_CTRL_NUM_GPU_ERRORS_RECOVERED: int
NV_CTRL_REFRESH_RATE_3: int
NV_CTRL_ONDEMAND_VBLANK_INTERRUPTS: int
NV_CTRL_ONDEMAND_VBLANK_INTERRUPTS_OFF: int
NV_CTRL_ONDEMAND_VBLANK_INTERRUPTS_ON: int
NV_CTRL_GPU_POWER_SOURCE: int
NV_CTRL_GPU_POWER_SOURCE_AC: int
NV_CTRL_GPU_POWER_SOURCE_BATTERY: int
NV_CTRL_GPU_CURRENT_PERFORMANCE_MODE: int
NV_CTRL_GPU_CURRENT_PERFORMANCE_MODE_DESKTOP: int
NV_CTRL_GPU_CURRENT_PERFORMANCE_MODE_MAXPERF: int
NV_CTRL_GLYPH_CACHE: int
NV_CTRL_GLYPH_CACHE_DISABLED: int
NV_CTRL_GLYPH_CACHE_ENABLED: int
NV_CTRL_GPU_CURRENT_PERFORMANCE_LEVEL: int
NV_CTRL_GPU_ADAPTIVE_CLOCK_STATE: int
NV_CTRL_GPU_ADAPTIVE_CLOCK_STATE_DISABLED: int
NV_CTRL_GPU_ADAPTIVE_CLOCK_STATE_ENABLED: int
NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED: int
NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED_FALSE: int
NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED_TRUE: int
NV_CTRL_GVO_SYNC_LOCK_STATUS: int
NV_CTRL_GVO_SYNC_LOCK_STATUS_UNLOCKED: int
NV_CTRL_GVO_SYNC_LOCK_STATUS_LOCKED: int
NV_CTRL_GVO_ANC_TIME_CODE_GENERATION: int
NV_CTRL_GVO_ANC_TIME_CODE_GENERATION_DISABLE: int
NV_CTRL_GVO_ANC_TIME_CODE_GENERATION_ENABLE: int
NV_CTRL_GVO_COMPOSITE: int
NV_CTRL_GVO_COMPOSITE_DISABLE: int
NV_CTRL_GVO_COMPOSITE_ENABLE: int
NV_CTRL_GVO_COMPOSITE_ALPHA_KEY: int
NV_CTRL_GVO_COMPOSITE_ALPHA_KEY_DISABLE: int
NV_CTRL_GVO_COMPOSITE_ALPHA_KEY_ENABLE: int
NV_CTRL_GVO_COMPOSITE_LUMA_KEY_RANGE: int
NV_CTRL_GVO_COMPOSITE_CR_KEY_RANGE: int
NV_CTRL_GVO_COMPOSITE_CB_KEY_RANGE: int
NV_CTRL_GVO_COMPOSITE_NUM_KEY_RANGES: int
NV_CTRL_SWITCH_TO_DISPLAYS: int
NV_CTRL_NOTEBOOK_DISPLAY_CHANGE_LID_EVENT: int
NV_CTRL_NOTEBOOK_INTERNAL_LCD: int
NV_CTRL_DEPTH_30_ALLOWED: int
NV_CTRL_MODE_SET_EVENT: int
NV_CTRL_OPENGL_AA_LINE_GAMMA_VALUE: int
NV_CTRL_VCSC_HIGH_PERF_MODE: int
NV_CTRL_VCSC_HIGH_PERF_MODE_DISABLE: int
NV_CTRL_VCSC_HIGH_PERF_MODE_ENABLE: int
NV_CTRL_DISPLAYPORT_LINK_RATE: int
NV_CTRL_DISPLAYPORT_LINK_RATE_DISABLED: int
NV_CTRL_DISPLAYPORT_LINK_RATE_1_62GBPS: int
NV_CTRL_DISPLAYPORT_LINK_RATE_2_70GBPS: int
NV_CTRL_STEREO_EYES_EXCHANGE: int
NV_CTRL_STEREO_EYES_EXCHANGE_OFF: int
NV_CTRL_STEREO_EYES_EXCHANGE_ON: int
NV_CTRL_NO_SCANOUT: int
NV_CTRL_NO_SCANOUT_DISABLED: int
NV_CTRL_NO_SCANOUT_ENABLED: int
NV_CTRL_GVO_CSC_CHANGED_EVENT: int
NV_CTRL_FRAMELOCK_SLAVEABLE: int
NV_CTRL_GVO_SYNC_TO_DISPLAY: int
NV_CTRL_GVO_SYNC_TO_DISPLAY_DISABLE: int
NV_CTRL_GVO_SYNC_TO_DISPLAY_ENABLE: int
NV_CTRL_X_SERVER_UNIQUE_ID: int
NV_CTRL_PIXMAP_CACHE: int
NV_CTRL_PIXMAP_CACHE_DISABLE: int
NV_CTRL_PIXMAP_CACHE_ENABLE: int
NV_CTRL_PIXMAP_CACHE_ROUNDING_SIZE_KB: int
NV_CTRL_IS_GVO_DISPLAY: int
NV_CTRL_IS_GVO_DISPLAY_FALSE: int
NV_CTRL_IS_GVO_DISPLAY_TRUE: int
NV_CTRL_PCI_ID: int
NV_CTRL_GVO_FULL_RANGE_COLOR: int
NV_CTRL_GVO_FULL_RANGE_COLOR_DISABLED: int
NV_CTRL_GVO_FULL_RANGE_COLOR_ENABLED: int
NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE: int
NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE_FALSE: int
NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE_TRUE: int
NV_CTRL_GVO_ENABLE_RGB_DATA: int
NV_CTRL_GVO_ENABLE_RGB_DATA_DISABLE: int
NV_CTRL_GVO_ENABLE_RGB_DATA_ENABLE: int
NV_CTRL_IMAGE_SHARPENING_DEFAULT: int
NV_CTRL_PCI_DOMAIN: int
NV_CTRL_GVI_NUM_JACKS: int
NV_CTRL_GVI_MAX_LINKS_PER_STREAM: int
NV_CTRL_GVI_DETECTED_CHANNEL_BITS_PER_COMPONENT: int
NV_CTRL_GVI_BITS_PER_COMPONENT_UNKNOWN: int
NV_CTRL_GVI_BITS_PER_COMPONENT_8: int
NV_CTRL_GVI_BITS_PER_COMPONENT_10: int
NV_CTRL_GVI_BITS_PER_COMPONENT_12: int
NV_CTRL_GVI_REQUESTED_STREAM_BITS_PER_COMPONENT: int
NV_CTRL_GVI_DETECTED_CHANNEL_COMPONENT_SAMPLING: int
NV_CTRL_GVI_COMPONENT_SAMPLING_UNKNOWN: int
NV_CTRL_GVI_COMPONENT_SAMPLING_4444: int
NV_CTRL_GVI_COMPONENT_SAMPLING_4224: int
NV_CTRL_GVI_COMPONENT_SAMPLING_444: int
NV_CTRL_GVI_COMPONENT_SAMPLING_422: int
NV_CTRL_GVI_COMPONENT_SAMPLING_420: int
NV_CTRL_GVI_REQUESTED_STREAM_COMPONENT_SAMPLING: int
NV_CTRL_GVI_REQUESTED_STREAM_CHROMA_EXPAND: int
NV_CTRL_GVI_CHROMA_EXPAND_FALSE: int
NV_CTRL_GVI_CHROMA_EXPAND_TRUE: int
NV_CTRL_GVI_DETECTED_CHANNEL_COLOR_SPACE: int
NV_CTRL_GVI_COLOR_SPACE_UNKNOWN: int
NV_CTRL_GVI_COLOR_SPACE_GBR: int
NV_CTRL_GVI_COLOR_SPACE_GBRA: int
NV_CTRL_GVI_COLOR_SPACE_GBRD: int
NV_CTRL_GVI_COLOR_SPACE_YCBCR: int
NV_CTRL_GVI_COLOR_SPACE_YCBCRA: int
NV_CTRL_GVI_COLOR_SPACE_YCBCRD: int
NV_CTRL_GVI_DETECTED_CHANNEL_LINK_ID: int
NV_CTRL_GVI_LINK_ID_UNKNOWN: int
NV_CTRL_GVI_DETECTED_CHANNEL_SMPTE352_IDENTIFIER: int
NV_CTRL_GVI_GLOBAL_IDENTIFIER: int
NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION: int
NV_CTRL_GPU_COOLER_MANUAL_CONTROL: int
NV_CTRL_GPU_COOLER_MANUAL_CONTROL_FALSE: int
NV_CTRL_GPU_COOLER_MANUAL_CONTROL_TRUE: int
NV_CTRL_THERMAL_COOLER_LEVEL: int
NV_CTRL_THERMAL_COOLER_LEVEL_SET_DEFAULT: int
NV_CTRL_THERMAL_COOLER_CONTROL_TYPE: int
NV_CTRL_THERMAL_COOLER_CONTROL_TYPE_NONE: int
NV_CTRL_THERMAL_COOLER_CONTROL_TYPE_TOGGLE: int
NV_CTRL_THERMAL_COOLER_CONTROL_TYPE_VARIABLE: int
NV_CTRL_THERMAL_COOLER_TARGET: int
NV_CTRL_THERMAL_COOLER_TARGET_NONE: int
NV_CTRL_THERMAL_COOLER_TARGET_GPU: int
NV_CTRL_THERMAL_COOLER_TARGET_MEMORY: int
NV_CTRL_THERMAL_COOLER_TARGET_POWER_SUPPLY: int
NV_CTRL_THERMAL_COOLER_TARGET_GPU_RELATED: int
NV_CTRL_GPU_ECC_SUPPORTED: int
NV_CTRL_GPU_ECC_SUPPORTED_FALSE: int
NV_CTRL_GPU_ECC_SUPPORTED_TRUE: int
NV_CTRL_GPU_ECC_STATUS: int
NV_CTRL_GPU_ECC_STATUS_DISABLED: int
NV_CTRL_GPU_ECC_STATUS_ENABLED: int
NV_CTRL_GPU_ECC_CONFIGURATION_SUPPORTED: int
NV_CTRL_GPU_ECC_CONFIGURATION_SUPPORTED_FALSE: int
NV_CTRL_GPU_ECC_CONFIGURATION_SUPPORTED_TRUE: int
NV_CTRL_GPU_ECC_CONFIGURATION: int
NV_CTRL_GPU_ECC_CONFIGURATION_DISABLED: int
NV_CTRL_GPU_ECC_CONFIGURATION_ENABLED: int
NV_CTRL_GPU_ECC_DEFAULT_CONFIGURATION: int
NV_CTRL_GPU_ECC_DEFAULT_CONFIGURATION_DISABLED: int
NV_CTRL_GPU_ECC_DEFAULT_CONFIGURATION_ENABLED: int
NV_CTRL_GPU_ECC_SINGLE_BIT_ERRORS: int
NV_CTRL_GPU_ECC_DOUBLE_BIT_ERRORS: int
NV_CTRL_GPU_ECC_AGGREGATE_SINGLE_BIT_ERRORS: int
NV_CTRL_GPU_ECC_AGGREGATE_DOUBLE_BIT_ERRORS: int
NV_CTRL_GPU_ECC_RESET_ERROR_STATUS: int
NV_CTRL_GPU_ECC_RESET_ERROR_STATUS_VOLATILE: int
NV_CTRL_GPU_ECC_RESET_ERROR_STATUS_AGGREGATE: int
NV_CTRL_GPU_POWER_MIZER_MODE: int
NV_CTRL_GPU_POWER_MIZER_MODE_ADAPTIVE: int
NV_CTRL_GPU_POWER_MIZER_MODE_PREFER_MAXIMUM_PERFORMANCE: int
NV_CTRL_GPU_POWER_MIZER_MODE_AUTO: int
NV_CTRL_GPU_POWER_MIZER_MODE_PREFER_CONSISTENT_PERFORMANCE: int
NV_CTRL_GVI_SYNC_OUTPUT_FORMAT: int
NV_CTRL_GVI_MAX_CHANNELS_PER_JACK: int
NV_CTRL_GVI_MAX_STREAMS: int
NV_CTRL_GVI_NUM_CAPTURE_SURFACES: int
NV_CTRL_OVERSCAN_COMPENSATION: int
NV_CTRL_GPU_PCIE_GENERATION: int
NV_CTRL_GPU_PCIE_GENERATION1: int
NV_CTRL_GPU_PCIE_GENERATION2: int
NV_CTRL_GPU_PCIE_GENERATION3: int
NV_CTRL_GVI_BOUND_GPU: int
NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT3: int
NV_CTRL_ACCELERATE_TRAPEZOIDS: int
NV_CTRL_ACCELERATE_TRAPEZOIDS_DISABLE: int
NV_CTRL_ACCELERATE_TRAPEZOIDS_ENABLE: int
NV_CTRL_GPU_CORES: int
NV_CTRL_GPU_MEMORY_BUS_WIDTH: int
NV_CTRL_GVI_TEST_MODE: int
NV_CTRL_GVI_TEST_MODE_DISABLE: int
NV_CTRL_GVI_TEST_MODE_ENABLE: int
NV_CTRL_COLOR_SPACE: int
NV_CTRL_COLOR_SPACE_RGB: int
NV_CTRL_COLOR_SPACE_YCbCr422: int
NV_CTRL_COLOR_SPACE_YCbCr444: int
NV_CTRL_COLOR_RANGE: int
NV_CTRL_COLOR_RANGE_FULL: int
NV_CTRL_COLOR_RANGE_LIMITED: int
NV_CTRL_GPU_SCALING_DEFAULT_TARGET: int
NV_CTRL_GPU_SCALING_DEFAULT_METHOD: int
NV_CTRL_DITHERING_MODE: int
NV_CTRL_DITHERING_MODE_AUTO: int
NV_CTRL_DITHERING_MODE_DYNAMIC_2X2: int
NV_CTRL_DITHERING_MODE_STATIC_2X2: int
NV_CTRL_DITHERING_MODE_TEMPORAL: int
NV_CTRL_CURRENT_DITHERING: int
NV_CTRL_CURRENT_DITHERING_DISABLED: int
NV_CTRL_CURRENT_DITHERING_ENABLED: int
NV_CTRL_CURRENT_DITHERING_MODE: int
NV_CTRL_CURRENT_DITHERING_MODE_NONE: int
NV_CTRL_CURRENT_DITHERING_MODE_DYNAMIC_2X2: int
NV_CTRL_CURRENT_DITHERING_MODE_STATIC_2X2: int
NV_CTRL_CURRENT_DITHERING_MODE_TEMPORAL: int
NV_CTRL_THERMAL_SENSOR_READING: int
NV_CTRL_THERMAL_SENSOR_PROVIDER: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_NONE: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_GPU_INTERNAL: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_ADM1032: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_ADT7461: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_MAX6649: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_MAX1617: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_LM99: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_LM89: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_LM64: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_G781: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_ADT7473: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_SBMAX6649: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_VBIOSEVT: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_OS: int
NV_CTRL_THERMAL_SENSOR_PROVIDER_UNKNOWN: int
NV_CTRL_THERMAL_SENSOR_TARGET: int
NV_CTRL_THERMAL_SENSOR_TARGET_NONE: int
NV_CTRL_THERMAL_SENSOR_TARGET_GPU: int
NV_CTRL_THERMAL_SENSOR_TARGET_MEMORY: int
NV_CTRL_THERMAL_SENSOR_TARGET_POWER_SUPPLY: int
NV_CTRL_THERMAL_SENSOR_TARGET_BOARD: int
NV_CTRL_THERMAL_SENSOR_TARGET_UNKNOWN: int
NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR: int
NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR_FALSE: int
NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR_TRUE: int
NV_CTRL_GPU_CURRENT_PROCESSOR_CLOCK_FREQS: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_NONE: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_INTERLACED: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_PROGRESSIVE: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_PSF: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_3G_LEVEL_A: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_3G_LEVEL_B: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_3G: int
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_3G_1080P_NO_12BPC: int
NV_CTRL_GPU_PCIE_MAX_LINK_SPEED: int
NV_CTRL_3D_VISION_PRO_RESET_TRANSCEIVER_TO_FACTORY_SETTINGS: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_INVALID: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_LOW_RANGE: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_MEDIUM_RANGE: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_HIGH_RANGE: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_COUNT: int
NV_CTRL_SYNCHRONOUS_PALETTE_UPDATES: int
NV_CTRL_SYNCHRONOUS_PALETTE_UPDATES_DISABLE: int
NV_CTRL_SYNCHRONOUS_PALETTE_UPDATES_ENABLE: int
NV_CTRL_DITHERING_DEPTH: int
NV_CTRL_DITHERING_DEPTH_AUTO: int
NV_CTRL_DITHERING_DEPTH_6_BITS: int
NV_CTRL_DITHERING_DEPTH_8_BITS: int
NV_CTRL_CURRENT_DITHERING_DEPTH: int
NV_CTRL_CURRENT_DITHERING_DEPTH_NONE: int
NV_CTRL_CURRENT_DITHERING_DEPTH_6_BITS: int
NV_CTRL_CURRENT_DITHERING_DEPTH_8_BITS: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL_FREQUENCY: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL_QUALITY: int
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL_COUNT: int
NV_CTRL_3D_VISION_PRO_PAIR_GLASSES: int
NV_CTRL_3D_VISION_PRO_PAIR_GLASSES_STOP: int
NV_CTRL_3D_VISION_PRO_PAIR_GLASSES_BEACON: int
NV_CTRL_3D_VISION_PRO_UNPAIR_GLASSES: int
NV_CTRL_3D_VISION_PRO_DISCOVER_GLASSES: int
NV_CTRL_3D_VISION_PRO_IDENTIFY_GLASSES: int
NV_CTRL_3D_VISION_PRO_GLASSES_SYNC_CYCLE: int
NV_CTRL_3D_VISION_PRO_GLASSES_MISSED_SYNC_CYCLES: int
NV_CTRL_3D_VISION_PRO_GLASSES_BATTERY_LEVEL: int
NV_CTRL_GVO_ANC_PARITY_COMPUTATION: int
NV_CTRL_GVO_ANC_PARITY_COMPUTATION_AUTO: int
NV_CTRL_GVO_ANC_PARITY_COMPUTATION_ON: int
NV_CTRL_GVO_ANC_PARITY_COMPUTATION_OFF: int
NV_CTRL_3D_VISION_PRO_GLASSES_PAIR_EVENT: int
NV_CTRL_3D_VISION_PRO_GLASSES_UNPAIR_EVENT: int
NV_CTRL_GPU_PCIE_CURRENT_LINK_WIDTH: int
NV_CTRL_GPU_PCIE_CURRENT_LINK_SPEED: int
NV_CTRL_GVO_AUDIO_BLANKING: int
NV_CTRL_GVO_AUDIO_BLANKING_DISABLE: int
NV_CTRL_GVO_AUDIO_BLANKING_ENABLE: int
NV_CTRL_CURRENT_METAMODE_ID: int
NV_CTRL_DISPLAY_ENABLED: int
NV_CTRL_DISPLAY_ENABLED_TRUE: int
NV_CTRL_DISPLAY_ENABLED_FALSE: int
NV_CTRL_FRAMELOCK_INCOMING_HOUSE_SYNC_RATE: int
NV_CTRL_FXAA: int
NV_CTRL_FXAA_DISABLE: int
NV_CTRL_FXAA_ENABLE: int
NV_CTRL_DISPLAY_RANDR_OUTPUT_ID: int
NV_CTRL_FRAMELOCK_DISPLAY_CONFIG: int
NV_CTRL_FRAMELOCK_DISPLAY_CONFIG_DISABLED: int
NV_CTRL_FRAMELOCK_DISPLAY_CONFIG_CLIENT: int
NV_CTRL_FRAMELOCK_DISPLAY_CONFIG_SERVER: int
NV_CTRL_TOTAL_DEDICATED_GPU_MEMORY: int
NV_CTRL_USED_DEDICATED_GPU_MEMORY: int
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_IMMEDIATE: int
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_IMMEDIATE_DISABLED: int
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_IMMEDIATE_ENABLED: int
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT: int
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT_DISABLED: int
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT_ENALED: int
NV_CTRL_DPY_HDMI_3D: int
NV_CTRL_DPY_HDMI_3D_DISABLED: int
NV_CTRL_DPY_HDMI_3D_ENABLED: int
NV_CTRL_BASE_MOSAIC: int
NV_CTRL_BASE_MOSAIC_DISABLED: int
NV_CTRL_BASE_MOSAIC_FULL: int
NV_CTRL_BASE_MOSAIC_LIMITED: int
NV_CTRL_MULTIGPU_MASTER_POSSIBLE: int
NV_CTRL_MULTIGPU_MASTER_POSSIBLE_FALSE: int
NV_CTRL_MULTIGPU_MASTER_POSSIBLE_TRUE: int
NV_CTRL_GPU_POWER_MIZER_DEFAULT_MODE: int
NV_CTRL_XV_SYNC_TO_DISPLAY_ID: int
NV_CTRL_XV_SYNC_TO_DISPLAY_ID_AUTO: int
NV_CTRL_BACKLIGHT_BRIGHTNESS: int
NV_CTRL_GPU_LOGO_BRIGHTNESS: int
NV_CTRL_GPU_SLI_LOGO_BRIGHTNESS: int
NV_CTRL_THERMAL_COOLER_SPEED: int
NV_CTRL_PALETTE_UPDATE_EVENT: int
NV_CTRL_VIDEO_ENCODER_UTILIZATION: int
NV_CTRL_GSYNC_ALLOWED: int
NV_CTRL_GSYNC_ALLOWED_FALSE: int
NV_CTRL_GSYNC_ALLOWED_TRUE: int
NV_CTRL_GPU_NVCLOCK_OFFSET: int
NV_CTRL_GPU_MEM_TRANSFER_RATE_OFFSET: int
NV_CTRL_VIDEO_DECODER_UTILIZATION: int
NV_CTRL_GPU_OVER_VOLTAGE_OFFSET: int
NV_CTRL_GPU_CURRENT_CORE_VOLTAGE: int
NV_CTRL_CURRENT_COLOR_SPACE: int
NV_CTRL_CURRENT_COLOR_SPACE_RGB: int
NV_CTRL_CURRENT_COLOR_SPACE_YCbCr422: int
NV_CTRL_CURRENT_COLOR_SPACE_YCbCr444: int
NV_CTRL_CURRENT_COLOR_SPACE_YCbCr420: int
NV_CTRL_CURRENT_COLOR_RANGE: int
NV_CTRL_CURRENT_COLOR_RANGE_FULL: int
NV_CTRL_CURRENT_COLOR_RANGE_LIMITED: int
NV_CTRL_SHOW_GSYNC_VISUAL_INDICATOR: int
NV_CTRL_SHOW_GSYNC_VISUAL_INDICATOR_FALSE: int
NV_CTRL_SHOW_GSYNC_VISUAL_INDICATOR_TRUE: int
NV_CTRL_THERMAL_COOLER_CURRENT_LEVEL: int
NV_CTRL_STEREO_SWAP_MODE: int
NV_CTRL_STEREO_SWAP_MODE_APPLICATION_CONTROL: int
NV_CTRL_STEREO_SWAP_MODE_PER_EYE: int
NV_CTRL_STEREO_SWAP_MODE_PER_EYE_PAIR: int
NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID: int
NV_CTRL_GPU_FRAMELOCK_FIRMWARE_UNSUPPORTED: int
NV_CTRL_GPU_FRAMELOCK_FIRMWARE_UNSUPPORTED_FALSE: int
NV_CTRL_GPU_FRAMELOCK_FIRMWARE_UNSUPPORTED_TRUE: int
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE: int
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_UNKNOWN: int
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_DISPLAYPORT: int
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_HDMI: int
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_DVI: int
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_VGA: int
NV_CTRL_DISPLAYPORT_IS_MULTISTREAM: int
NV_CTRL_DISPLAYPORT_SINK_IS_AUDIO_CAPABLE: int
NV_CTRL_GPU_NVCLOCK_OFFSET_ALL_PERFORMANCE_LEVELS: int
NV_CTRL_GPU_MEM_TRANSFER_RATE_OFFSET_ALL_PERFORMANCE_LEVELS: int
NV_CTRL_FRAMELOCK_FIRMWARE_VERSION: int
NV_CTRL_FRAMELOCK_FIRMWARE_MINOR_VERSION: int
NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR: int
NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR_FALSE: int
NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR_TRUE: int
NV_CTRL_LAST_ATTRIBUTE: int
NV_CTRL_STRING_PRODUCT_NAME: int
NV_CTRL_STRING_VBIOS_VERSION: int
NV_CTRL_STRING_NVIDIA_DRIVER_VERSION: int
NV_CTRL_STRING_DISPLAY_DEVICE_NAME: int
NV_CTRL_STRING_TV_ENCODER_NAME: int
NV_CTRL_STRING_GVIO_FIRMWARE_VERSION: int
NV_CTRL_STRING_GVO_FIRMWARE_VERSION: int
NV_CTRL_STRING_CURRENT_MODELINE: int
NV_CTRL_STRING_ADD_MODELINE: int
NV_CTRL_STRING_DELETE_MODELINE: int
NV_CTRL_STRING_CURRENT_METAMODE: int
NV_CTRL_STRING_CURRENT_METAMODE_VERSION_1: int
NV_CTRL_STRING_ADD_METAMODE: int
NV_CTRL_STRING_DELETE_METAMODE: int
NV_CTRL_STRING_VCSC_PRODUCT_NAME: int
NV_CTRL_STRING_VCSC_PRODUCT_ID: int
NV_CTRL_STRING_VCSC_SERIAL_NUMBER: int
NV_CTRL_STRING_VCSC_BUILD_DATE: int
NV_CTRL_STRING_VCSC_FIRMWARE_VERSION: int
NV_CTRL_STRING_VCSC_FIRMWARE_REVISION: int
NV_CTRL_STRING_VCSC_HARDWARE_VERSION: int
NV_CTRL_STRING_VCSC_HARDWARE_REVISION: int
NV_CTRL_STRING_MOVE_METAMODE: int
NV_CTRL_STRING_VALID_HORIZ_SYNC_RANGES: int
NV_CTRL_STRING_VALID_VERT_REFRESH_RANGES: int
NV_CTRL_STRING_SCREEN_RECTANGLE: int
NV_CTRL_STRING_XINERAMA_SCREEN_INFO: int
NV_CTRL_STRING_NVIDIA_XINERAMA_INFO_ORDER: int
NV_CTRL_STRING_TWINVIEW_XINERAMA_INFO_ORDER: int
NV_CTRL_STRING_SLI_MODE: int
NV_CTRL_STRING_PERFORMANCE_MODES: int
NV_CTRL_STRING_VCSC_FAN_STATUS: int
NV_CTRL_STRING_VCSC_TEMPERATURES: int
NV_CTRL_STRING_VCSC_PSU_INFO: int
NV_CTRL_STRING_GVIO_VIDEO_FORMAT_NAME: int
NV_CTRL_STRING_GVO_VIDEO_FORMAT_NAME: int
NV_CTRL_STRING_GPU_CURRENT_CLOCK_FREQS: int
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_HARDWARE_REVISION: int
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_VERSION_A: int
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_DATE_A: int
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_VERSION_B: int
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_DATE_B: int
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_ADDRESS: int
NV_CTRL_STRING_3D_VISION_PRO_GLASSES_FIRMWARE_VERSION_A: int
NV_CTRL_STRING_3D_VISION_PRO_GLASSES_FIRMWARE_DATE_A: int
NV_CTRL_STRING_3D_VISION_PRO_GLASSES_ADDRESS: int
NV_CTRL_STRING_3D_VISION_PRO_GLASSES_NAME: int
NV_CTRL_STRING_CURRENT_METAMODE_VERSION_2: int
NV_CTRL_STRING_DISPLAY_NAME_TYPE_BASENAME: int
NV_CTRL_STRING_DISPLAY_NAME_TYPE_ID: int
NV_CTRL_STRING_DISPLAY_NAME_DP_GUID: int
NV_CTRL_STRING_DISPLAY_NAME_EDID_HASH: int
NV_CTRL_STRING_DISPLAY_NAME_TARGET_INDEX: int
NV_CTRL_STRING_DISPLAY_NAME_RANDR: int
NV_CTRL_STRING_GPU_UUID: int
NV_CTRL_STRING_GPU_UTILIZATION: int
NV_CTRL_STRING_MULTIGPU_MODE: int
NV_CTRL_STRING_PRIME_OUTPUTS_DATA: int
NV_CTRL_STRING_LAST_ATTRIBUTE: int
NV_CTRL_BINARY_DATA_EDID: int
NV_CTRL_BINARY_DATA_MODELINES: int
NV_CTRL_BINARY_DATA_METAMODES: int
NV_CTRL_BINARY_DATA_METAMODES_VERSION_1: int
NV_CTRL_BINARY_DATA_XSCREENS_USING_GPU: int
NV_CTRL_BINARY_DATA_GPUS_USED_BY_XSCREEN: int
NV_CTRL_BINARY_DATA_GPUS_USING_FRAMELOCK: int
NV_CTRL_BINARY_DATA_DISPLAY_VIEWPORT: int
NV_CTRL_BINARY_DATA_FRAMELOCKS_USED_BY_GPU: int
NV_CTRL_BINARY_DATA_GPUS_USING_VCSC: int
NV_CTRL_BINARY_DATA_VCSCS_USED_BY_GPU: int
NV_CTRL_BINARY_DATA_COOLERS_USED_BY_GPU: int
NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN: int
NV_CTRL_BINARY_DATA_THERMAL_SENSORS_USED_BY_GPU: int
NV_CTRL_BINARY_DATA_GLASSES_PAIRED_TO_3D_VISION_PRO_TRANSCEIVER: int
NV_CTRL_BINARY_DATA_DISPLAY_TARGETS: int
NV_CTRL_BINARY_DATA_DISPLAYS_CONNECTED_TO_GPU: int
NV_CTRL_BINARY_DATA_METAMODES_VERSION_2: int
NV_CTRL_BINARY_DATA_DISPLAYS_ENABLED_ON_XSCREEN: int
NV_CTRL_BINARY_DATA_DISPLAYS_ASSIGNED_TO_XSCREEN: int
NV_CTRL_BINARY_DATA_GPU_FLAGS: int
NV_CTRL_BINARY_DATA_GPU_FLAGS_STEREO_DISPLAY_TRANSFORM_EXCLUSIVE: int
NV_CTRL_BINARY_DATA_GPU_FLAGS_OVERLAY_DISPLAY_TRANSFORM_EXCLUSIVE: int
NV_CTRL_BINARY_DATA_GPU_FLAGS_DEPTH_8_DISPLAY_TRANSFORM_EXCLUSIVE: int
NV_CTRL_BINARY_DATA_DISPLAYS_ON_GPU: int
NV_CTRL_BINARY_DATA_LAST_ATTRIBUTE: int
NV_CTRL_STRING_OPERATION_ADD_METAMODE: int
NV_CTRL_STRING_OPERATION_GTF_MODELINE: int
NV_CTRL_STRING_OPERATION_CVT_MODELINE: int
NV_CTRL_STRING_OPERATION_BUILD_MODEPOOL: int
NV_CTRL_STRING_OPERATION_GVI_CONFIGURE_STREAMS: int
NV_CTRL_STRING_OPERATION_PARSE_METAMODE: int
NV_CTRL_STRING_OPERATION_LAST_ATTRIBUTE: int
X_nvCtrlQueryExtension: int
X_nvCtrlQueryAttribute: int
X_nvCtrlQueryStringAttribute: int
X_nvCtrlQueryValidAttributeValues: int
X_nvCtrlSetStringAttribute: int
X_nvCtrlSetAttributeAndGetStatus: int
X_nvCtrlQueryBinaryData: int
X_nvCtrlQueryTargetCount: int
X_nvCtrlStringOperation: int
ATTRIBUTE_TYPE_UNKNOWN: int
ATTRIBUTE_TYPE_INTEGER: int
ATTRIBUTE_TYPE_BITMASK: int
ATTRIBUTE_TYPE_BOOL: int
ATTRIBUTE_TYPE_RANGE: int
ATTRIBUTE_TYPE_INT_BITS: int
ATTRIBUTE_TYPE_READ: int
ATTRIBUTE_TYPE_WRITE: int
ATTRIBUTE_TYPE_DISPLAY: int
ATTRIBUTE_TYPE_GPU: int
ATTRIBUTE_TYPE_FRAMELOCK: int
ATTRIBUTE_TYPE_X_SCREEN: int
ATTRIBUTE_TYPE_XINERAMA: int
ATTRIBUTE_TYPE_VCSC: int
NV_CTRL_TARGET_TYPE_X_SCREEN: int
NV_CTRL_TARGET_TYPE_GPU: int
NV_CTRL_TARGET_TYPE_FRAMELOCK: int
NV_CTRL_TARGET_TYPE_VCSC: int
NV_CTRL_TARGET_TYPE_GVI: int
NV_CTRL_TARGET_TYPE_COOLER: int
NV_CTRL_TARGET_TYPE_THERMAL_SENSOR: int
NV_CTRL_TARGET_TYPE_3D_VISION_PRO_TRANSCEIVER: int
NV_CTRL_TARGET_TYPE_DISPLAY: int

class Target:
    def id(self) -> int: ...
    def type(self) -> int: ...

class Gpu(Target):
    def __init__(self, ngpu: int = ...) -> None: ...

class Screen(Target):
    def __init__(self, nscr: int = ...) -> None: ...

class Cooler(Target):
    def __init__(self, nfan: int = ...) -> None: ...

class NVCtrlQueryTargetCountReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryAttributeReplyRequest(rq.ReplyRequest): ...
class NVCtrlSetAttributeAndGetStatusReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryStringAttributeReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryValidAttributeValuesReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryBinaryDataReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryListCard32ReplyRequest(rq.ReplyRequest): ...



NoValue: int
XValue: int
YValue: int
WidthValue: int
HeightValue: int
AllValues: int
XNegative: int
YNegative: int
USPosition: int
USSize: int
PPosition: int
PSize: int
PMinSize: int
PMaxSize: int
PResizeInc: int
PAspect: int
PBaseSize: int
PWinGravity: int
PAllHints: int
InputHint: int
StateHint: int
IconPixmapHint: int
IconWindowHint: int
IconPositionHint: int
IconMaskHint: int
WindowGroupHint: int
MessageHint: int
UrgencyHint: int
AllHints: int
WithdrawnState: int
NormalState: int
IconicState: int
DontCareState: int
ZoomState: int
InactiveState: int
RectangleOut: int
RectangleIn: int
RectanglePart: int
VisualNoMask: int
VisualIDMask: int
VisualScreenMask: int
VisualDepthMask: int
VisualClassMask: int
VisualRedMaskMask: int
VisualGreenMaskMask: int
VisualBlueMaskMask: int
VisualColormapSizeMask: int
VisualBitsPerRGBMask: int
VisualAllMask: int
ReleaseByFreeingColormap: int
BitmapSuccess: int
BitmapOpenFailed: int
BitmapFileInvalid: int
BitmapNoMemory: int
XCSUCCESS: int
XCNOMEM: int
XCNOENT: int



NONE: int
ParentRelative: int
CopyFromParent: int
PointerWindow: int
InputFocus: int
PointerRoot: int
AnyPropertyType: int
AnyKey: int
AnyButton: int
AllTemporary: int
CurrentTime: int
NoSymbol: int
NoEventMask: int
KeyPressMask: int
KeyReleaseMask: int
ButtonPressMask: int
ButtonReleaseMask: int
EnterWindowMask: int
LeaveWindowMask: int
PointerMotionMask: int
PointerMotionHintMask: int
Button1MotionMask: int
Button2MotionMask: int
Button3MotionMask: int
Button4MotionMask: int
Button5MotionMask: int
ButtonMotionMask: int
KeymapStateMask: int
ExposureMask: int
VisibilityChangeMask: int
StructureNotifyMask: int
ResizeRedirectMask: int
SubstructureNotifyMask: int
SubstructureRedirectMask: int
FocusChangeMask: int
PropertyChangeMask: int
ColormapChangeMask: int
OwnerGrabButtonMask: int
KeyPress: int
KeyRelease: int
ButtonPress: int
ButtonRelease: int
MotionNotify: int
EnterNotify: int
LeaveNotify: int
FocusIn: int
FocusOut: int
KeymapNotify: int
Expose: int
GraphicsExpose: int
NoExpose: int
VisibilityNotify: int
CreateNotify: int
DestroyNotify: int
UnmapNotify: int
MapNotify: int
MapRequest: int
ReparentNotify: int
ConfigureNotify: int
ConfigureRequest: int
GravityNotify: int
ResizeRequest: int
CirculateNotify: int
CirculateRequest: int
PropertyNotify: int
SelectionClear: int
SelectionRequest: int
SelectionNotify: int
ColormapNotify: int
ClientMessage: int
MappingNotify: int
LASTEvent: int
ShiftMask: int
LockMask: int
ControlMask: int
Mod1Mask: int
Mod2Mask: int
Mod3Mask: int
Mod4Mask: int
Mod5Mask: int
ShiftMapIndex: int
LockMapIndex: int
ControlMapIndex: int
Mod1MapIndex: int
Mod2MapIndex: int
Mod3MapIndex: int
Mod4MapIndex: int
Mod5MapIndex: int
Button1Mask: int
Button2Mask: int
Button3Mask: int
Button4Mask: int
Button5Mask: int
AnyModifier: int
Button1: int
Button2: int
Button3: int
Button4: int
Button5: int
NotifyNormal: int
NotifyGrab: int
NotifyUngrab: int
NotifyWhileGrabbed: int
NotifyHint: int
NotifyAncestor: int
NotifyVirtual: int
NotifyInferior: int
NotifyNonlinear: int
NotifyNonlinearVirtual: int
NotifyPointer: int
NotifyPointerRoot: int
NotifyDetailNone: int
VisibilityUnobscured: int
VisibilityPartiallyObscured: int
VisibilityFullyObscured: int
PlaceOnTop: int
PlaceOnBottom: int
FamilyInternet: int
FamilyDECnet: int
FamilyChaos: int
FamilyServerInterpreted: int
FamilyInternetV6: int
PropertyNewValue: int
PropertyDelete: int
ColormapUninstalled: int
ColormapInstalled: int
GrabModeSync: int
GrabModeAsync: int
GrabSuccess: int
AlreadyGrabbed: int
GrabInvalidTime: int
GrabNotViewable: int
GrabFrozen: int
AsyncPointer: int
SyncPointer: int
ReplayPointer: int
AsyncKeyboard: int
SyncKeyboard: int
ReplayKeyboard: int
AsyncBoth: int
SyncBoth: int
RevertToNone: int
RevertToPointerRoot: int
RevertToParent: int
Success: int
BadRequest: int
BadValue: int
BadWindow: int
BadPixmap: int
BadAtom: int
BadCursor: int
BadFont: int
BadMatch: int
BadDrawable: int
BadAccess: int
BadAlloc: int
BadColor: int
BadGC: int
BadIDChoice: int
BadName: int
BadLength: int
BadImplementation: int
FirstExtensionError: int
LastExtensionError: int
InputOutput: int
InputOnly: int
CWBackPixmap: int
CWBackPixel: int
CWBorderPixmap: int
CWBorderPixel: int
CWBitGravity: int
CWWinGravity: int
CWBackingStore: int
CWBackingPlanes: int
CWBackingPixel: int
CWOverrideRedirect: int
CWSaveUnder: int
CWEventMask: int
CWDontPropagate: int
CWColormap: int
CWCursor: int
CWX: int
CWY: int
CWWidth: int
CWHeight: int
CWBorderWidth: int
CWSibling: int
CWStackMode: int
ForgetGravity: int
NorthWestGravity: int
NorthGravity: int
NorthEastGravity: int
WestGravity: int
CenterGravity: int
EastGravity: int
SouthWestGravity: int
SouthGravity: int
SouthEastGravity: int
StaticGravity: int
UnmapGravity: int
NotUseful: int
WhenMapped: int
Always: int
IsUnmapped: int
IsUnviewable: int
IsViewable: int
SetModeInsert: int
SetModeDelete: int
DestroyAll: int
RetainPermanent: int
RetainTemporary: int
Above: int
Below: int
TopIf: int
BottomIf: int
Opposite: int
RaiseLowest: int
LowerHighest: int
PropModeReplace: int
PropModePrepend: int
PropModeAppend: int
GXclear: int
GXand: int
GXandReverse: int
GXcopy: int
GXandInverted: int
GXnoop: int
GXxor: int
GXor: int
GXnor: int
GXequiv: int
GXinvert: int
GXorReverse: int
GXcopyInverted: int
GXorInverted: int
GXnand: int
GXset: int
LineSolid: int
LineOnOffDash: int
LineDoubleDash: int
CapNotLast: int
CapButt: int
CapRound: int
CapProjecting: int
JoinMiter: int
JoinRound: int
JoinBevel: int
FillSolid: int
FillTiled: int
FillStippled: int
FillOpaqueStippled: int
EvenOddRule: int
WindingRule: int
ClipByChildren: int
IncludeInferiors: int
Unsorted: int
YSorted: int
YXSorted: int
YXBanded: int
CoordModeOrigin: int
CoordModePrevious: int
Complex: int
Nonconvex: int
Convex: int
ArcChord: int
ArcPieSlice: int
GCFunction: int
GCPlaneMask: int
GCForeground: int
GCBackground: int
GCLineWidth: int
GCLineStyle: int
GCCapStyle: int
GCJoinStyle: int
GCFillStyle: int
GCFillRule: int
GCTile: int
GCStipple: int
GCTileStipXOrigin: int
GCTileStipYOrigin: int
GCFont: int
GCSubwindowMode: int
GCGraphicsExposures: int
GCClipXOrigin: int
GCClipYOrigin: int
GCClipMask: int
GCDashOffset: int
GCDashList: int
GCArcMode: int
GCLastBit: int
FontLeftToRight: int
FontRightToLeft: int
FontChange: int
XYBitmap: int
XYPixmap: int
ZPixmap: int
AllocNone: int
AllocAll: int
DoRed: int
DoGreen: int
DoBlue: int
CursorShape: int
TileShape: int
StippleShape: int
AutoRepeatModeOff: int
AutoRepeatModeOn: int
AutoRepeatModeDefault: int
LedModeOff: int
LedModeOn: int
KBKeyClickPercent: int
KBBellPercent: int
KBBellPitch: int
KBBellDuration: int
KBLed: int
KBLedMode: int
KBKey: int
KBAutoRepeatMode: int
MappingSuccess: int
MappingBusy: int
MappingFailed: int
MappingModifier: int
MappingKeyboard: int
MappingPointer: int
DontPreferBlanking: int
PreferBlanking: int
DefaultBlanking: int
DisableScreenSaver: int
DisableScreenInterval: int
DontAllowExposures: int
AllowExposures: int
DefaultExposures: int
ScreenSaverReset: int
ScreenSaverActive: int
HostInsert: int
HostDelete: int
EnableAccess: int
DisableAccess: int
StaticGray: int
GrayScale: int
StaticColor: int
PseudoColor: int
TrueColor: int
DirectColor: int
LSBFirst: int
MSBFirst: int



XK_Thai_kokai: int
XK_Thai_khokhai: int
XK_Thai_khokhuat: int
XK_Thai_khokhwai: int
XK_Thai_khokhon: int
XK_Thai_khorakhang: int
XK_Thai_ngongu: int
XK_Thai_chochan: int
XK_Thai_choching: int
XK_Thai_chochang: int
XK_Thai_soso: int
XK_Thai_chochoe: int
XK_Thai_yoying: int
XK_Thai_dochada: int
XK_Thai_topatak: int
XK_Thai_thothan: int
XK_Thai_thonangmontho: int
XK_Thai_thophuthao: int
XK_Thai_nonen: int
XK_Thai_dodek: int
XK_Thai_totao: int
XK_Thai_thothung: int
XK_Thai_thothahan: int
XK_Thai_thothong: int
XK_Thai_nonu: int
XK_Thai_bobaimai: int
XK_Thai_popla: int
XK_Thai_phophung: int
XK_Thai_fofa: int
XK_Thai_phophan: int
XK_Thai_fofan: int
XK_Thai_phosamphao: int
XK_Thai_moma: int
XK_Thai_yoyak: int
XK_Thai_rorua: int
XK_Thai_ru: int
XK_Thai_loling: int
XK_Thai_lu: int
XK_Thai_wowaen: int
XK_Thai_sosala: int
XK_Thai_sorusi: int
XK_Thai_sosua: int
XK_Thai_hohip: int
XK_Thai_lochula: int
XK_Thai_oang: int
XK_Thai_honokhuk: int
XK_Thai_paiyannoi: int
XK_Thai_saraa: int
XK_Thai_maihanakat: int
XK_Thai_saraaa: int
XK_Thai_saraam: int
XK_Thai_sarai: int
XK_Thai_saraii: int
XK_Thai_saraue: int
XK_Thai_sarauee: int
XK_Thai_sarau: int
XK_Thai_sarauu: int
XK_Thai_phinthu: int
XK_Thai_maihanakat_maitho: int
XK_Thai_baht: int
XK_Thai_sarae: int
XK_Thai_saraae: int
XK_Thai_sarao: int
XK_Thai_saraaimaimuan: int
XK_Thai_saraaimaimalai: int
XK_Thai_lakkhangyao: int
XK_Thai_maiyamok: int
XK_Thai_maitaikhu: int
XK_Thai_maiek: int
XK_Thai_maitho: int
XK_Thai_maitri: int
XK_Thai_maichattawa: int
XK_Thai_thanthakhat: int
XK_Thai_nikhahit: int
XK_Thai_leksun: int
XK_Thai_leknung: int
XK_Thai_leksong: int
XK_Thai_leksam: int
XK_Thai_leksi: int
XK_Thai_lekha: int
XK_Thai_lekhok: int
XK_Thai_lekchet: int
XK_Thai_lekpaet: int
XK_Thai_lekkao: int



num_glyphs: int
X_cursor: int
arrow: int
based_arrow_down: int
based_arrow_up: int
boat: int
bogosity: int
bottom_left_corner: int
bottom_right_corner: int
bottom_side: int
bottom_tee: int
box_spiral: int
center_ptr: int
circle: int
clock: int
coffee_mug: int
cross: int
cross_reverse: int
crosshair: int
diamond_cross: int
dot: int
dotbox: int
double_arrow: int
draft_large: int
draft_small: int
draped_box: int
exchange: int
fleur: int
gobbler: int
gumby: int
hand1: int
hand2: int
heart: int
icon: int
iron_cross: int
left_ptr: int
left_side: int
left_tee: int
leftbutton: int
ll_angle: int
lr_angle: int
man: int
middlebutton: int
mouse: int
pencil: int
pirate: int
plus: int
question_arrow: int
right_ptr: int
right_side: int
right_tee: int
rightbutton: int
rtl_logo: int
sailboat: int
sb_down_arrow: int
sb_h_double_arrow: int
sb_left_arrow: int
sb_right_arrow: int
sb_up_arrow: int
sb_v_double_arrow: int
shuttle: int
sizing: int
spider: int
spraycan: int
star: int
target: int
tcross: int
top_left_arrow: int
top_left_corner: int
top_right_corner: int
top_side: int
top_tee: int
trek: int
ul_angle: int
umbrella: int
ur_angle: int
watch: int
xterm: int



from typing import type_check_only

from Xlib._typing import ErrorHandler
from Xlib.protocol import display

# Workaround for pytype crash. Should be Xlib.display._BaseDisplay
@type_check_only
class _BaseDisplay(display.Display):
    def __init__(self, display: str | None = ...) -> None: ...
    def get_atom(self, atomname: str, only_if_exists: bool = ...) -> int: ...

class Resource:
    display: _BaseDisplay
    id: int
    owner: int
    def __init__(self, display: _BaseDisplay, rid: int, owner: int = ...) -> None: ...
    def __resource__(self) -> int: ...
    def kill_client(self, onerror: ErrorHandler[object] | None = ...) -> None: ...



from Xlib._typing import Unused
from Xlib.display import Display
from Xlib.protocol import rq
from Xlib.xobject import resource

extname: str
SecurityClientTrusted: int
SecurityClientUntrusted: int
SecurityAuthorizationRevokedMask: int
AUTHID = rq.Card32

class QueryVersion(rq.ReplyRequest): ...

def query_version(self: Display | resource.Resource) -> QueryVersion: ...

class SecurityGenerateAuthorization(rq.ReplyRequest): ...

def generate_authorization(
    self: Display | resource.Resource,
    auth_proto: str,
    auth_data: bytes | bytearray = ...,
    timeout: int | None = ...,
    trust_level: int | None = ...,
    group: int | None = ...,
    event_mask: int | None = ...,
) -> SecurityGenerateAuthorization: ...

class SecurityRevokeAuthorization(rq.Request): ...

def revoke_authorization(self: Display | resource.Resource, authid: int) -> SecurityRevokeAuthorization: ...
def init(disp: Display, info: Unused) -> None: ...



XK_Serbian_dje: int
XK_Macedonia_gje: int
XK_Cyrillic_io: int
XK_Ukrainian_ie: int
XK_Ukranian_je: int
XK_Macedonia_dse: int
XK_Ukrainian_i: int
XK_Ukranian_i: int
XK_Ukrainian_yi: int
XK_Ukranian_yi: int
XK_Cyrillic_je: int
XK_Serbian_je: int
XK_Cyrillic_lje: int
XK_Serbian_lje: int
XK_Cyrillic_nje: int
XK_Serbian_nje: int
XK_Serbian_tshe: int
XK_Macedonia_kje: int
XK_Byelorussian_shortu: int
XK_Cyrillic_dzhe: int
XK_Serbian_dze: int
XK_numerosign: int
XK_Serbian_DJE: int
XK_Macedonia_GJE: int
XK_Cyrillic_IO: int
XK_Ukrainian_IE: int
XK_Ukranian_JE: int
XK_Macedonia_DSE: int
XK_Ukrainian_I: int
XK_Ukranian_I: int
XK_Ukrainian_YI: int
XK_Ukranian_YI: int
XK_Cyrillic_JE: int
XK_Serbian_JE: int
XK_Cyrillic_LJE: int
XK_Serbian_LJE: int
XK_Cyrillic_NJE: int
XK_Serbian_NJE: int
XK_Serbian_TSHE: int
XK_Macedonia_KJE: int
XK_Byelorussian_SHORTU: int
XK_Cyrillic_DZHE: int
XK_Serbian_DZE: int
XK_Cyrillic_yu: int
XK_Cyrillic_a: int
XK_Cyrillic_be: int
XK_Cyrillic_tse: int
XK_Cyrillic_de: int
XK_Cyrillic_ie: int
XK_Cyrillic_ef: int
XK_Cyrillic_ghe: int
XK_Cyrillic_ha: int
XK_Cyrillic_i: int
XK_Cyrillic_shorti: int
XK_Cyrillic_ka: int
XK_Cyrillic_el: int
XK_Cyrillic_em: int
XK_Cyrillic_en: int
XK_Cyrillic_o: int
XK_Cyrillic_pe: int
XK_Cyrillic_ya: int
XK_Cyrillic_er: int
XK_Cyrillic_es: int
XK_Cyrillic_te: int
XK_Cyrillic_u: int
XK_Cyrillic_zhe: int
XK_Cyrillic_ve: int
XK_Cyrillic_softsign: int
XK_Cyrillic_yeru: int
XK_Cyrillic_ze: int
XK_Cyrillic_sha: int
XK_Cyrillic_e: int
XK_Cyrillic_shcha: int
XK_Cyrillic_che: int
XK_Cyrillic_hardsign: int
XK_Cyrillic_YU: int
XK_Cyrillic_A: int
XK_Cyrillic_BE: int
XK_Cyrillic_TSE: int
XK_Cyrillic_DE: int
XK_Cyrillic_IE: int
XK_Cyrillic_EF: int
XK_Cyrillic_GHE: int
XK_Cyrillic_HA: int
XK_Cyrillic_I: int
XK_Cyrillic_SHORTI: int
XK_Cyrillic_KA: int
XK_Cyrillic_EL: int
XK_Cyrillic_EM: int
XK_Cyrillic_EN: int
XK_Cyrillic_O: int
XK_Cyrillic_PE: int
XK_Cyrillic_YA: int
XK_Cyrillic_ER: int
XK_Cyrillic_ES: int
XK_Cyrillic_TE: int
XK_Cyrillic_U: int
XK_Cyrillic_ZHE: int
XK_Cyrillic_VE: int
XK_Cyrillic_SOFTSIGN: int
XK_Cyrillic_YERU: int
XK_Cyrillic_ZE: int
XK_Cyrillic_SHA: int
XK_Cyrillic_E: int
XK_Cyrillic_SHCHA: int
XK_Cyrillic_CHE: int
XK_Cyrillic_HARDSIGN: int



XK_emspace: int
XK_enspace: int
XK_em3space: int
XK_em4space: int
XK_digitspace: int
XK_punctspace: int
XK_thinspace: int
XK_hairspace: int
XK_emdash: int
XK_endash: int
XK_signifblank: int
XK_ellipsis: int
XK_doubbaselinedot: int
XK_onethird: int
XK_twothirds: int
XK_onefifth: int
XK_twofifths: int
XK_threefifths: int
XK_fourfifths: int
XK_onesixth: int
XK_fivesixths: int
XK_careof: int
XK_figdash: int
XK_leftanglebracket: int
XK_decimalpoint: int
XK_rightanglebracket: int
XK_marker: int
XK_oneeighth: int
XK_threeeighths: int
XK_fiveeighths: int
XK_seveneighths: int
XK_trademark: int
XK_signaturemark: int
XK_trademarkincircle: int
XK_leftopentriangle: int
XK_rightopentriangle: int
XK_emopencircle: int
XK_emopenrectangle: int
XK_leftsinglequotemark: int
XK_rightsinglequotemark: int
XK_leftdoublequotemark: int
XK_rightdoublequotemark: int
XK_prescription: int
XK_minutes: int
XK_seconds: int
XK_latincross: int
XK_hexagram: int
XK_filledrectbullet: int
XK_filledlefttribullet: int
XK_filledrighttribullet: int
XK_emfilledcircle: int
XK_emfilledrect: int
XK_enopencircbullet: int
XK_enopensquarebullet: int
XK_openrectbullet: int
XK_opentribulletup: int
XK_opentribulletdown: int
XK_openstar: int
XK_enfilledcircbullet: int
XK_enfilledsqbullet: int
XK_filledtribulletup: int
XK_filledtribulletdown: int
XK_leftpointer: int
XK_rightpointer: int
XK_club: int
XK_diamond: int
XK_heart: int
XK_maltesecross: int
XK_dagger: int
XK_doubledagger: int
XK_checkmark: int
XK_ballotcross: int
XK_musicalsharp: int
XK_musicalflat: int
XK_malesymbol: int
XK_femalesymbol: int
XK_telephone: int
XK_telephonerecorder: int
XK_phonographcopyright: int
XK_caret: int
XK_singlelowquotemark: int
XK_doublelowquotemark: int
XK_cursor: int



PRIMARY: int
SECONDARY: int
ARC: int
ATOM: int
BITMAP: int
CARDINAL: int
COLORMAP: int
CURSOR: int
CUT_BUFFER0: int
CUT_BUFFER1: int
CUT_BUFFER2: int
CUT_BUFFER3: int
CUT_BUFFER4: int
CUT_BUFFER5: int
CUT_BUFFER6: int
CUT_BUFFER7: int
DRAWABLE: int
FONT: int
INTEGER: int
PIXMAP: int
POINT: int
RECTANGLE: int
RESOURCE_MANAGER: int
RGB_COLOR_MAP: int
RGB_BEST_MAP: int
RGB_BLUE_MAP: int
RGB_DEFAULT_MAP: int
RGB_GRAY_MAP: int
RGB_GREEN_MAP: int
RGB_RED_MAP: int
STRING: int
VISUALID: int
WINDOW: int
WM_COMMAND: int
WM_HINTS: int
WM_CLIENT_MACHINE: int
WM_ICON_NAME: int
WM_ICON_SIZE: int
WM_NAME: int
WM_NORMAL_HINTS: int
WM_SIZE_HINTS: int
WM_ZOOM_HINTS: int
MIN_SPACE: int
NORM_SPACE: int
MAX_SPACE: int
END_SPACE: int
SUPERSCRIPT_X: int
SUPERSCRIPT_Y: int
SUBSCRIPT_X: int
SUBSCRIPT_Y: int
UNDERLINE_POSITION: int
UNDERLINE_THICKNESS: int
STRIKEOUT_ASCENT: int
STRIKEOUT_DESCENT: int
ITALIC_ANGLE: int
X_HEIGHT: int
QUAD_WIDTH: int
WEIGHT: int
POINT_SIZE: int
RESOLUTION: int
COPYRIGHT: int
NOTICE: int
FONT_NAME: int
FAMILY_NAME: int
FULL_NAME: int
CAP_HEIGHT: int
WM_CLASS: int
WM_TRANSIENT_FOR: int
LAST_PREDEFINED: int



XK_leftradical: int
XK_topleftradical: int
XK_horizconnector: int
XK_topintegral: int
XK_botintegral: int
XK_vertconnector: int
XK_topleftsqbracket: int
XK_botleftsqbracket: int
XK_toprightsqbracket: int
XK_botrightsqbracket: int
XK_topleftparens: int
XK_botleftparens: int
XK_toprightparens: int
XK_botrightparens: int
XK_leftmiddlecurlybrace: int
XK_rightmiddlecurlybrace: int
XK_topleftsummation: int
XK_botleftsummation: int
XK_topvertsummationconnector: int
XK_botvertsummationconnector: int
XK_toprightsummation: int
XK_botrightsummation: int
XK_rightmiddlesummation: int
XK_lessthanequal: int
XK_notequal: int
XK_greaterthanequal: int
XK_integral: int
XK_therefore: int
XK_variation: int
XK_infinity: int
XK_nabla: int
XK_approximate: int
XK_similarequal: int
XK_ifonlyif: int
XK_implies: int
XK_identical: int
XK_radical: int
XK_includedin: int
XK_includes: int
XK_intersection: int
XK_union: int
XK_logicaland: int
XK_logicalor: int
XK_partialderivative: int
XK_function: int
XK_leftarrow: int
XK_uparrow: int
XK_rightarrow: int
XK_downarrow: int



from _typeshed import FileDescriptor, StrOrBytesPath
from collections.abc import Callable
from typing import Optional, TypeVar
from typing_extensions import TypeAlias

from Xlib.error import XError
from Xlib.protocol.rq import Request

_T = TypeVar("_T")
ErrorHandler: TypeAlias = Callable[[XError, Optional[Request]], _T]
Unused: TypeAlias = object
OpenFile: TypeAlias = StrOrBytesPath | FileDescriptor



XK_blank: int
XK_soliddiamond: int
XK_checkerboard: int
XK_ht: int
XK_ff: int
XK_cr: int
XK_lf: int
XK_nl: int
XK_vt: int
XK_lowrightcorner: int
XK_uprightcorner: int
XK_upleftcorner: int
XK_lowleftcorner: int
XK_crossinglines: int
XK_horizlinescan1: int
XK_horizlinescan3: int
XK_horizlinescan5: int
XK_horizlinescan7: int
XK_horizlinescan9: int
XK_leftt: int
XK_rightt: int
XK_bott: int
XK_topt: int
XK_vertbar: int



XK_leftcaret: int
XK_rightcaret: int
XK_downcaret: int
XK_upcaret: int
XK_overbar: int
XK_downtack: int
XK_upshoe: int
XK_downstile: int
XK_underbar: int
XK_jot: int
XK_quad: int
XK_uptack: int
XK_circle: int
XK_upstile: int
XK_downshoe: int
XK_rightshoe: int
XK_leftshoe: int
XK_lefttack: int
XK_righttack: int
